@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3979 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-03-06 15:50:04 -0800 (Tue, 06 Mar 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -135,8 +135,7 @@ doMain( const int argc, const char* argv[] )
 	  const cmtk::Xform* xform = it->first;
 	  const cmtk::UniformVolume* volume = it->second;
 
-	  cmtk::Vector3D vx( v );
-	  xform->ApplyInPlace( vx );
+	  const cmtk::Vector3D vx( xform->Apply( v ) );
 	  	  
 	  cmtk::ProbeInfo probeInfo;
 	  if ( volume->ProbeNoXform( probeInfo, vx ) )
