@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3750 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-01-26 13:59:12 -0800 (Thu, 26 Jan 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -42,8 +42,8 @@
 #include <Base/cmtkSplineWarpXform.h>
 #include <Base/cmtkDeformationField.h>
 
-const char* inXformPath = NULL;
-const char* outXformPath = NULL;
+std::string inXformPath;
+std::string outXformPath;
 
 float Fractional = -1;
 bool DeformationOnly = false;
@@ -55,7 +55,7 @@ doMain ( const int argc, const char* argv[] )
     {
     cmtk::CommandLine cl;
     cl.SetProgramInfo( cmtk::CommandLine::PRG_TITLE, "Convert nonrigd transformations." );
-    cl.SetProgramInfo( cmtk::CommandLine::PRG_DESCR, "This tool converts nonrigid BB-spline free-format deformation coordinate transformations between different representations (e.g., absolute vs. relative vectors). Also creates fractional transformations." );
+    cl.SetProgramInfo( cmtk::CommandLine::PRG_DESCR, "This tool converts nonrigid B-spline free-format deformation coordinate transformations between different representations (e.g., absolute vs. relative vectors). Also creates fractional transformations." );
 
     typedef cmtk::CommandLine::Key Key;
     cl.AddOption( Key( 'f', "fractional" ), &Fractional, "Write fractional deformation. Range: 0=affine to 1=full nonrigid; Default: 1" );
@@ -79,8 +79,16 @@ doMain ( const int argc, const char* argv[] )
     {
     cmtk::AffineXform::SmartPtr initialAffine = splineWarpXform->GetInitialAffineXform();
 
-    splineWarpXform->ReplaceInitialAffine( cmtk::AffineXform::SmartPtr( new cmtk::AffineXform ) );
-
+    try
+      {
+      splineWarpXform->ReplaceInitialAffine();
+      }
+    catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+      {
+      cmtk::StdErr << "ERROR: singular matrix encountered in call to cmtk::WarpXform::ReplaceInitialAffine()\n";
+      throw cmtk::ExitException( 1 );
+      }
+    
     if ( (Fractional >= 0) && (Fractional <= 1) )
       {
       const size_t numberOfControlPoints = splineWarpXform->GetNumberOfControlPoints();
@@ -97,7 +105,15 @@ doMain ( const int argc, const char* argv[] )
     
     if ( ! DeformationOnly )
       {
-      splineWarpXform->ReplaceInitialAffine( initialAffine );
+      try
+	{
+	splineWarpXform->ReplaceInitialAffine( initialAffine );
+	}
+      catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+	{
+	cmtk::StdErr << "ERROR: singular matrix encountered in call to cmtk::WarpXform::ReplaceInitialAffine()\n";
+	throw cmtk::ExitException( 1 );
+	}
       }
     }
   
