@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2012 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5010 $
+//  $Revision: 5203 $
 //
-//  $LastChangedDate: 2013-11-07 16:52:03 -0800 (Thu, 07 Nov 2013) $
+//  $LastChangedDate: 2014-02-11 10:52:46 -0800 (Tue, 11 Feb 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -162,8 +162,10 @@ public:
   /// Build a volume list by traversing a directory.
   void AppendFromDirectory( const std::string& path, const char *wildcard );
   
-  /// Write all volumes in this list.
-  void WriteVolumes();
+  /** Write all volumes in this list.
+   *\return Return code - 0, no problems; 3, at least one volume was not written correctly (e.g., due to non-uniform slice spacing).
+   */
+  int WriteVolumes();
 
 private:
   /// Stored floating point tolerance.
@@ -182,9 +184,11 @@ PutNumberAndSanitize( const std::string& path, const std::string& numberString )
     return cmtk::StrReplace( cmtk::StrReplace( path, "%n", numberString ), "%N", "-" + numberString );
 }
 
-void
+int
 VolumeList::WriteVolumes() 
 {
+  int returnCode = 0;
+  
   size_t cntSingleImages = 0;
 
   std::map<std::string,Self> pathToVolumeMap;
@@ -270,9 +274,16 @@ VolumeList::WriteVolumes()
 
       cmtk::UniformVolume::SmartConstPtr volume = it->second[0]->WriteImage( uniquePath.c_str(), EmbedInfo );
 
-      if ( volume && WriteXML )
+      if ( volume )
 	{
-	it->second[0]->WriteXML( (uniquePath+".xml").c_str(), *volume, IncludeIdentifiers );
+	if ( WriteXML )
+	  {
+	  it->second[0]->WriteXML( (uniquePath+".xml").c_str(), *volume, IncludeIdentifiers );
+	  }
+	}
+      else
+	{
+	returnCode = 3;
 	}
       }
     else
@@ -289,13 +300,22 @@ VolumeList::WriteVolumes()
 
 	cmtk::UniformVolume::SmartConstPtr volume = it->second[i]->WriteImage( uniquePath.c_str(), EmbedInfo );
 
-	if ( volume && WriteXML )
+	if ( volume) 
 	  {
-	  it->second[i]->WriteXML( (uniquePath + ".xml").c_str(), *volume, IncludeIdentifiers );
+	  if ( WriteXML )
+	    {
+	    it->second[i]->WriteXML( (uniquePath + ".xml").c_str(), *volume, IncludeIdentifiers );
+	    }
+	  }
+	else
+	  {
+	  returnCode = 3;
 	  }
 	}
       }
     }
+
+  return returnCode;
 }
 
 
@@ -320,7 +340,7 @@ VolumeList::AddImageFile( ImageFileDICOM::SmartConstPtr& newImage )
       }
     }    
 
-  ImageStackDICOM::SmartPtr newImageStack( new ImageStackDICOM( Tolerance ) );
+  ImageStackDICOM::SmartPtr newImageStack( new ImageStackDICOM( this->m_Tolerance ) );
   newImageStack->AddImageFile( newImage );
   push_back( newImageStack );    
 }
@@ -528,7 +548,8 @@ doMain ( const int argc, const char *argv[] )
     cl.AddSwitch( Key( "write-single-slices" ), &WriteSingleSlices, true, "Also write output images for single-slice DICOM files that could not be assigned to any 3D stacks. By default, these are skipped." );
     cl.AddSwitch( Key( "ignore-acq-number" ), &IgnoreAcquisitionNumber, true, "Ignore 'AcquisitionNumber' tag for image grouping, i.e., do not separate stacks based on this tag." );
     cl.AddSwitch( Key( "no-orientation-check" ), &DisableOrientationCheck, true, "Disable checking of image orientations (to avoid rounding issues)" );
-    cl.AddOption( Key( "tolerance" ), &Tolerance, "Tolerance for floating-point comparisons (must be >= 0; 0 = exact matches only; default: 1e-5)" );
+    cl.AddOption( Key( "tolerance" ), &Tolerance, "Tolerance for floating-point comparisons (must be >= 0; 0 = exact matches only; default: 1e-5). "
+		  "If one or more volumes cannot be stacked because of non-uniform slice spacing that exceeds this threshold, dcm2image will return an exit code of 3." );
     cl.EndGroup();
 
     cl.AddParameterVector( &SearchRootDirVector, "SearchDirList", "List of directories to search for DICOM files. Subdirectories are also search if '--recurse' option is used." );
@@ -554,9 +575,7 @@ doMain ( const int argc, const char *argv[] )
     volumeList.AppendFromDirectory( *it, "*" );
     }
   
-  volumeList.WriteVolumes();
-
-  return 0;
+  return volumeList.WriteVolumes();
 }
 
 #include "cmtkSafeMain"
