@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4344 $
+//  $Revision: 4975 $
 //
-//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
+//  $LastChangedDate: 2013-10-11 13:53:00 -0700 (Fri, 11 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -58,8 +58,8 @@
 #include <map>
 #include <vector>
 
-const char* InputFilePath = NULL;
-const char* OutputFilePath = NULL;
+std::string InputFilePath;
+std::string OutputFilePath;
 
 cmtk::Types::DataItem PaddingValue = 0;
 bool PaddingFlag = false;
@@ -79,11 +79,11 @@ int NumberOfIterations = 20;
 bool RegionalIntensityTruncation = true;
 double ConstraintWeightLNorm = 0;
 
-const char* ReferenceImagePath = NULL;
-const char* InjectedImagePath = NULL;
+std::string ReferenceImagePath;
+std::string InjectedImagePath;
 
-const char* ExportXformsPath = NULL;
-const char* ImportXformsPath = NULL;
+std::string ExportXformsPath;
+std::string ImportXformsPath;
 
 std::map<size_t,float> PassWeights;
 
@@ -94,7 +94,7 @@ CallbackSetPassWeight( const char* argv )
 {
   int pass = 0;
   float weight = 1.0;
-  if ( 2 == sscanf( argv, "%d:%f", &pass, &weight ) )
+  if ( 2 == sscanf( argv, "%3d:%10f", &pass, &weight ) )
     {
     PassWeights[pass] = weight;
     }
@@ -138,7 +138,7 @@ GetReconstructedImage( cmtk::UniformVolume::SmartPtr& volume, cmtk::UniformVolum
     xformsToPassImages = volRecon.GetTransformationsToPassImages();
     }
   
-  if ( ExportXformsPath )
+  if ( !ExportXformsPath.empty() )
     {
     cmtk::ClassStreamOutput stream( ExportXformsPath, cmtk::ClassStreamOutput::MODE_WRITE );
     if ( stream.IsValid() )
@@ -157,7 +157,7 @@ GetReconstructedImage( cmtk::UniformVolume::SmartPtr& volume, cmtk::UniformVolum
 
   cmtk::DebugOutput( 2 ) << "Volume injection...\n";
   volRecon.VolumeInjectionAnisotropic( InjectionKernelSigma, InjectionKernelRadius );
-  if ( InjectedImagePath )
+  if ( !InjectedImagePath.empty() )
     {
     cmtk::UniformVolume::SmartPtr outputImage = volRecon.GetCorrectedImage();
     if ( !WriteImagesAsFloat && outputImage->GetData()->GetType() != volume->GetData()->GetType() )
@@ -280,7 +280,7 @@ doMain( const int argc, const char* argv[] )
     }
 
   cmtk::UniformVolume::SmartPtr refImage;
-  if ( ReferenceImagePath )
+  if ( !ReferenceImagePath.empty() )
     {
     refImage = cmtk::UniformVolume::SmartPtr( cmtk::VolumeIO::ReadOriented( ReferenceImagePath ) );
     if ( ! refImage || ! refImage->GetData() )
@@ -291,7 +291,7 @@ doMain( const int argc, const char* argv[] )
     }
 
   std::vector<cmtk::Xform::SmartPtr> xformsToPassImages;
-  if ( ImportXformsPath )
+  if ( !ImportXformsPath.empty() )
     {
     cmtk::ClassStreamInput stream( ImportXformsPath );
     if ( stream.IsValid() )
@@ -301,8 +301,16 @@ doMain( const int argc, const char* argv[] )
       cmtk::AffineXform xform;
       for ( unsigned int pass = 0; pass < NumberOfPasses; ++pass )
 	{
-	stream >> xform;
-	xformsToPassImages.push_back( cmtk::Xform::SmartPtr( xform.Clone() ) );
+	try
+	  {
+	  stream >> xform;
+	  }
+	catch ( const cmtk::Exception& ex )
+	  {
+	  cmtk::StdErr << "ERROR: reading transformation failed - " << ex.what() << "\n";
+	  throw cmtk::ExitException( 1 );
+	  }
+	xformsToPassImages.push_back( cmtk::Xform::SmartPtr( xform.Clone() ) );	  
 	}
       }
     else
