@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4355 $
+//  $Revision: 4866 $
 //
-//  $LastChangedDate: 2012-05-21 15:44:49 -0700 (Mon, 21 May 2012) $
+//  $LastChangedDate: 2013-09-24 10:01:06 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -47,9 +47,9 @@ int
 doMain
 ( const int argc, const char *argv[] )
 {
-  const char* inputImagePath = NULL;
-  const char* maskImagePath = NULL;
-  const char* outputImagePath = NULL;
+  std::string inputImagePath;
+  std::string maskImagePath;
+  std::string outputImagePath;
 
   bool writeProbMaps = false;
   bool priorsInitOnly = false;
@@ -106,7 +106,7 @@ doMain
   cmtk::UniformVolume::SmartPtr inputImage = cmtk::VolumeIO::ReadOriented( inputImagePath );
 
   cmtk::UniformVolume::SmartConstPtr maskImage = inputImage;
-  if ( maskImagePath )
+  if ( !maskImagePath.empty() )
     {
     maskImage = cmtk::VolumeIO::ReadOriented( maskImagePath );
     if ( ! inputImage->GridMatches( *(maskImage) ) )
@@ -121,7 +121,7 @@ doMain
   std::vector<cmtk::UniformVolume::SmartConstPtr> priorImages( nClasses );
   for ( size_t k = 0; k < nClasses; ++k )
     {
-    priorImages[k] = cmtk::VolumeIO::ReadOriented( priorImagePaths[k].c_str() );
+    priorImages[k] = cmtk::VolumeIO::ReadOriented( priorImagePaths[k] );
 
     if ( ! inputImage->GridMatches( *(priorImages[k]) ) )
       {
@@ -159,7 +159,7 @@ doMain
   for ( size_t i = 0; i < nIterations; ++i )
     {
 #pragma omp parallel for
-    for ( size_t k = 0; k < nClasses; ++k )
+    for ( int k = 0; k < nClasses; ++k )
       {
       classMu[k] = pTotal[k] = 0;
       for ( size_t n = 0; n < nPixels; ++n )
@@ -187,15 +187,15 @@ doMain
       classSigma[k] = sqrt( classSigma[k] / pTotal[k] );
       }
     
-    cmtk::StdOut.printf( "Iteration %d\n", i );
+    cmtk::StdOut.printf( "Iteration %u\n", i );
     for ( size_t k = 0; k < nClasses; ++k )
       {
-      cmtk::StdOut.printf( "Class %d: %f +/- %f\t", k, classMu[k], classSigma[k] );
+      cmtk::StdOut.printf( "Class %u: %f +/- %f\t", k, classMu[k], classSigma[k] );
       }
     cmtk::StdOut << "\n";
 
 #pragma omp parallel for    
-    for ( size_t n = 0; n < nPixels; ++n )
+    for ( int n = 0; n < static_cast<int>( nPixels ); ++n )
       {
       if ( maskImage->GetDataAt( n ) > 0 )
 	{
@@ -226,7 +226,7 @@ doMain
     char path[PATH_MAX+1];
     for ( size_t k = 0; k < nClasses; ++k )
       {
-      strncpy( path, outputImagePath, PATH_MAX );
+      strncpy( path, outputImagePath.c_str(), PATH_MAX );
       path[PATH_MAX] = 0; // for safety - terminate string
 
       char* slash = strrchr( path, '/' );
@@ -237,13 +237,13 @@ doMain
       if ( ! period )
 	period = path + strlen( path );
       
-      snprintf( period, PATH_MAX - (period-path), "_prob%d%s", static_cast<int>( 1+k ), outputImagePath + (period-path) );
+      snprintf( period, PATH_MAX - (period-path), "_prob%d%s", static_cast<int>( 1+k ), outputImagePath.c_str() + (period-path) );
       cmtk::VolumeIO::Write( *(pMaps[k]), path );
       }
     }
   
 #pragma omp parallel for
-  for ( size_t n = 0; n < nPixels; ++n )
+  for ( int n = 0; n < static_cast<int>( nPixels ); ++n )
     {
     if ( maskImage->GetDataAt( n ) > 0 )
       {
