@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4538 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -131,8 +131,16 @@ doMain( const int argc, const char *argv[] )
     }
   
   cmtk::AffineXform::SmartPtr inverseAffineXform( NULL );
-  if ( affineXform )
-    inverseAffineXform = affineXform->GetInverse();
+  try
+    {
+    if ( affineXform )
+      inverseAffineXform = affineXform->GetInverse();
+    }
+  catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+    {
+    cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::AffineXform::GetInverse()\n";
+    throw cmtk::ExitException( 1 );
+    }
 
   const cmtk::Types::Coordinate globalScaling = (splineWarp) ? splineWarp->GetGlobalScaling() : affineXform->GetGlobalScaling();
 
@@ -185,7 +193,7 @@ doMain( const int argc, const char *argv[] )
 	{
 	break;
 	}
-      numRead = sscanf( line, "%f %f %f", xyz, xyz+1, xyz+2 );
+      numRead = sscanf( line, "%20f %20f %20f", xyz, xyz+1, xyz+2 );
       }
     
     if ( numRead == 3 ) 
