@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4344 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -56,8 +56,8 @@
 #include <map>
 #include <vector>
 
-const char* InputFilePath = NULL;
-const char* OutputFilePath = NULL;
+std::string InputFilePath;
+std::string OutputFilePath;
 
 int InterleaveAxis = -1;
 unsigned int NumberOfPasses = 2;
@@ -79,11 +79,11 @@ int NumberOfIterations = 20;
 bool RegionalIntensityTruncation = true;
 double ConstraintWeightLNorm = 0;
 
-const char* ReferenceImagePath = NULL;
-const char* InjectedImagePath = NULL;
+std::string ReferenceImagePath;
+std::string InjectedImagePath;
 
-const char* ExportXformsPath = NULL;
-const char* ImportXformsPath = NULL;
+std::string ExportXformsPath;
+std::string ImportXformsPath;
 
 std::map<size_t,float> PassWeights;
 
@@ -94,7 +94,7 @@ CallbackSetPassWeight( const char* argv )
 {
   int pass = 0;
   float weight = 1.0;
-  if ( 2 == sscanf( argv, "%d:%f", &pass, &weight ) )
+  if ( 2 == sscanf( argv, "%4d:%10f", &pass, &weight ) )
     {
     PassWeights[pass] = weight;
     }
@@ -138,7 +138,7 @@ GetReconstructedImage( cmtk::UniformVolume::SmartPtr& volume, cmtk::UniformVolum
     xformsToPassImages = volRecon.GetTransformationsToPassImages();
     }
   
-  if ( ExportXformsPath )
+  if ( !ExportXformsPath.empty() )
     {
     cmtk::ClassStreamOutput stream( ExportXformsPath, cmtk::ClassStreamOutput::MODE_WRITE );
     if ( stream.IsValid() )
@@ -156,8 +156,17 @@ GetReconstructedImage( cmtk::UniformVolume::SmartPtr& volume, cmtk::UniformVolum
     }
 
   cmtk::DebugOutput( 2 ) << "Volume injection...\n";
-  volRecon.VolumeInjectionIsotropic( InjectionKernelSigma, InjectionKernelRadius );
-  if ( InjectedImagePath )
+  try
+    {
+    volRecon.VolumeInjectionIsotropic( InjectionKernelSigma, InjectionKernelRadius );
+    }
+  catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+    {
+    cmtk::StdErr << "ERROR: singular coordinate transformation matrix encountered in cmtk::DeblurringVolumeReconstruction::VolumeInjectionIsotropic\n";
+    throw cmtk::ExitException( 1 );
+    }
+
+  if ( !InjectedImagePath.empty() )
     {
     cmtk::UniformVolume::SmartPtr outputImage = volRecon.GetCorrectedImage();
     if ( !WriteImagesAsFloat && outputImage->GetData()->GetType() != volume->GetData()->GetType() )
@@ -247,7 +256,7 @@ doMain( const int argc, const char* argv[] )
   catch ( const cmtk::CommandLine::Exception& e )
     {
     cmtk::StdErr << e << "\n";
-    return 1;
+    throw cmtk::ExitException( 1 );
     }
 
   /*
@@ -257,22 +266,22 @@ doMain( const int argc, const char* argv[] )
   if ( ! volume || ! volume->GetData() )
     {
     cmtk::StdErr << "ERROR: Could not read image " << InputFilePath << "\n";
-    return 1;
+    throw cmtk::ExitException( 1 );
     }
 
   cmtk::UniformVolume::SmartPtr refImage;
-  if ( ReferenceImagePath )
+  if ( !ReferenceImagePath.empty() )
     {
     refImage = cmtk::UniformVolume::SmartPtr( cmtk::VolumeIO::ReadOriented( ReferenceImagePath ) );
     if ( ! refImage || ! refImage->GetData() )
       {
       cmtk::StdErr << "ERROR: Could not read image " << ReferenceImagePath << "\n";
-      return 1;
+      throw cmtk::ExitException( 1 );
       }
     }
 
   std::vector<cmtk::Xform::SmartPtr> xformsToPassImages;
-  if ( ImportXformsPath )
+  if ( !ImportXformsPath.empty() )
     {
     cmtk::ClassStreamInput stream( ImportXformsPath );
     if ( stream.IsValid() )
@@ -282,13 +291,22 @@ doMain( const int argc, const char* argv[] )
       cmtk::AffineXform xform;
       for ( unsigned int pass = 0; pass < NumberOfPasses; ++pass )
 	{
-	stream >> xform;
+	try
+	  {
+	  stream >> xform;
+	  }
+	catch ( const cmtk::Exception& ex )
+	  {
+	  cmtk::StdErr << "ERROR: " << ex.what() << "\n";
+	  throw cmtk::ExitException( 1 );
+	  }
 	xformsToPassImages.push_back( cmtk::Xform::SmartPtr( xform.Clone() ) );
 	}
       }
     else
       {
       cmtk::StdErr << "ERROR: Could not open transformation file" << ImportXformsPath << "\n";
+      throw cmtk::ExitException( 1 );
       }
     }
 
