@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  Copyright 1997-2011 Torsten Rohlfing
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4237 $
+//  $Revision: 4923 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:20 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2013-10-04 10:01:17 -0700 (Fri, 04 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -55,8 +55,15 @@ bool DetachedHeader = true;
 void
 SetDims( const char* arg )
 {
-  sscanf( arg, "%d,%d,%d", &DimsX, &DimsY, &DimsZ );
-  PutDims = true;
+  if ( 3 == sscanf( arg, "%6d,%6d,%6d", &DimsX, &DimsY, &DimsZ ) )
+    {
+    PutDims = true;
+    }
+  else
+    {
+    cmtk::StdErr << "ERROR: could not parse X,Y,Z dimensions from argument '" << arg << "'\n";
+    throw cmtk::ExitException( 1 );
+    }
 }
 
 float DeltaX = 1.0;
@@ -67,8 +74,15 @@ bool PutDeltas = false;
 void
 SetDeltas( const char* arg )
 {
-  sscanf( arg, "%f,%f,%f", &DeltaX, &DeltaY, &DeltaZ );
-  PutDeltas = true;
+  if ( 3 == sscanf( arg, "%15f,%15f,%15f", &DeltaX, &DeltaY, &DeltaZ ) )
+    {
+    PutDeltas = true;
+    }
+  else
+    {
+    cmtk::StdErr << "ERROR: could not parse X,Y,Z pixel size from argument '" << arg << "'\n";
+    throw cmtk::ExitException( 1 );
+    }
 }
 
 cmtk::ScalarDataType DataType = cmtk::TYPE_NONE;
@@ -99,8 +113,8 @@ doMain( const int argc, const char* argv[] )
 
     cl.AddOption( Key( 'O', "offset" ), &Offset, "Binary data file offset", &PutOffset );
 
+    cl.AddSwitch( Key( 'b', "byte" ), &DataType, cmtk::TYPE_BYTE, "8 bits, unsigned (this is the default)" );
     cl.AddSwitch( Key( 'c', "char" ), &DataType, cmtk::TYPE_CHAR, "8 bits, signed" );
-    cl.AddSwitch( Key( 'b', "byte" ), &DataType, cmtk::TYPE_BYTE, "8 bits, unsigned" );
     cl.AddSwitch( Key( 's', "short" ), &DataType, cmtk::TYPE_SHORT, "16 bits, signed" );
     cl.AddSwitch( Key( 'u', "ushort" ), &DataType, cmtk::TYPE_USHORT, "16 bits, unsigned" );
     cl.AddSwitch( Key( 'i', "int" ), &DataType, cmtk::TYPE_INT, "32 bits signed" );
@@ -199,8 +213,6 @@ doMain( const int argc, const char* argv[] )
     switch ( DataType ) 
       {
       default:
-	header.datatype = DT_UNKNOWN;
-	header.bitpix = 0;
       case cmtk::TYPE_BYTE:
 	header.datatype = DT_UNSIGNED_CHAR;
 	header.bitpix = 8 * sizeof(byte);
@@ -235,7 +247,7 @@ doMain( const int argc, const char* argv[] )
   if ( Description )
     {
     cmtk::DebugOutput( 1 ) << "Setting image description\n";    
-    strncpy( header.descrip, Description, 80 );
+    memcpy( header.descrip, Description, std::min<size_t>( strlen( Description )+1, 80 ) );
     }
 
 #ifdef _MSC_VER
