@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5091 $
+//  $Revision: 5157 $
 //
-//  $LastChangedDate: 2013-12-03 23:42:09 -0800 (Tue, 03 Dec 2013) $
+//  $LastChangedDate: 2014-01-12 14:04:53 -0800 (Sun, 12 Jan 2014) $
 //
 //  $LastChangedBy: torsten_at_home $
 //
@@ -58,7 +58,7 @@
 #  include <Registration/cmtkImageXformDB.h>
 #endif
 
-bool JacobianCorrectGlobal = true;
+bool JacobianCorrectGlobal = false;
 bool MassPreservingReformat = false;
 
 bool TargetMask = false;
