@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3628 $
+//  $Revision: 5074 $
 //
-//  $LastChangedDate: 2011-12-09 14:32:21 -0800 (Fri, 09 Dec 2011) $
+//  $LastChangedDate: 2013-12-02 14:26:35 -0800 (Mon, 02 Dec 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -57,6 +57,10 @@
 #  include <sys/stat.h>
 #endif
 
+#ifdef HAVE_IEEEFP_H
+#  include <ieeefp.h>
+#endif
+
 #include <algorithm>
 
 bool Padding0 = false;
@@ -72,14 +76,14 @@ cmtk::UniformVolume::SmartPtr Volume1;
 
 bool OutsideBG = false;
 
-const char *imagePath0 = NULL;
-const char *imagePath1 = NULL;
+std::string imagePath0;
+std::string imagePath1;
 
-const char* MaskFileName = NULL;
+std::string MaskFileName;
 
 unsigned int ForceMaxLabel = 0;
 
-const char* HistogramTextFileName = NULL;
+std::string HistogramTextFileName;
 
 bool 
 ParseCommandLine( const int argc, const char* argv[] )
@@ -162,9 +166,9 @@ AnalyseStudies
   bool insideMask = true;
   for ( size_t r = 0; r < numberOfVoxels; ++r ) 
     {
-    bool dataExist0 = data0->Get( value0, r );
-    
-    bool dataExist1 = data1->Get( value1, r );
+    const bool dataExist0 = data0->Get( value0, r ) && finite( value0 );
+
+    bool dataExist1 = data1->Get( value1, r ) && finite( value1 );
     if ( ! dataExist1 && OutsideBG )
       {
       value1 = 0;
@@ -228,16 +232,23 @@ AnalyseStudies
 	countVoxelsUnequal++;
       }
     }
-  
-  fprintf( stdout, "\nCL\trecog\tsubst\treject\treliab\nCL-all\t%.4f\t%.4f\t%.4f\t%.4f\n",
-	   1.0*recog / numberOfVoxels, 1.0*subst / numberOfVoxels, 1.0*reject / numberOfVoxels, 1.0 * recog / (numberOfVoxels - reject) );
-  fprintf( stdout, "CL-fg\t%.4f\t%.4f\t%.4f\t%.4f\n",
-	   1.0 * recogFG / voxelCountFG, 1.0 * substFG / voxelCountFG, 1.0 * rejectFG / voxelCountFG, 1.0 * recogFG / (voxelCountFG - rejectFG) );
+
+  if ( numberOfVoxels && (numberOfVoxels != reject) )
+    {
+    fprintf( stdout, "\nCL\trecog\tsubst\treject\treliab\nCL-all\t%.4f\t%.4f\t%.4f\t%.4f\n", 1.0*recog / numberOfVoxels, 1.0*subst / numberOfVoxels, 1.0*reject / numberOfVoxels, 1.0 * recog / (numberOfVoxels - reject) );
+    }
+
+  if ( voxelCountFG && (voxelCountFG != rejectFG ) )
+    {
+    fprintf( stdout, "CL-fg\t%.4f\t%.4f\t%.4f\t%.4f\n", 1.0 * recogFG / voxelCountFG, 1.0 * substFG / voxelCountFG, 1.0 * rejectFG / voxelCountFG, 1.0 * recogFG / (voxelCountFG - rejectFG) );
+    }
   
   if ( mask ) 
     {
-    fprintf( stdout, "CL-mask\t%.4f\t%.4f\t%.4f\t%.4f\n",
-	     1.0 * recogM / voxelCountM, 1.0 * substM / voxelCountM, 1.0 * rejectM / voxelCountM, 1.0 * recogM / (voxelCountM - rejectM) );
+    if ( voxelCountM && (voxelCountM != rejectM ) )
+      {
+      fprintf( stdout, "CL-mask\t%.4f\t%.4f\t%.4f\t%.4f\n", 1.0 * recogM / voxelCountM, 1.0 * substM / voxelCountM, 1.0 * rejectM / voxelCountM, 1.0 * recogM / (voxelCountM - rejectM) );
+      }
     }
   fputs( "\n", stdout );
   
@@ -262,7 +273,7 @@ doMain ( const int argc, const char* argv[] )
     }
   
   cmtk::TypedArray::SmartPtr mask;
-  if ( MaskFileName ) 
+  if ( !MaskFileName.empty() ) 
     {
     cmtk::UniformVolume::SmartPtr maskVolume( cmtk::VolumeIO::ReadOriented( MaskFileName ) );
     if ( maskVolume )
@@ -297,14 +308,17 @@ doMain ( const int argc, const char* argv[] )
   histogram->GetMarginalEntropies( hX, hY );
   const double hXY = histogram->GetJointEntropy();
   
-  fprintf( stdout, "STAT\tN\tHX\tHY\nSTATval\t%d\t%.5f\t%.5f\n\n", voxelCount, hX, hY );
-  
-  fprintf( stdout, "SIM\tNDIFF\tDMAX\trDMAX\tMSD\tMAD\tNCC\tHXY\tMI\tNMI\nSIMval\t%d\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\n",
-	   countVoxelsUnequal, maxDifference, maxRelDifference, sumSq / voxelCount, sumAbs / voxelCount, ccMetric.Get(), hXY, hX + hY - hXY, ( hX + hY ) / hXY );
-  
-  if ( HistogramTextFileName )
+  fprintf( stdout, "STAT\tN\tHX\tHY\nSTATval\t%u\t%.5f\t%.5f\n\n", voxelCount, hX, hY );
+
+  if ( voxelCount )
     {
-    FILE *file = fopen( HistogramTextFileName, "w" );
+    fprintf( stdout, "SIM\tNDIFF\tDMAX\trDMAX\tMSD\tMAD\tNCC\tHXY\tMI\tNMI\nSIMval\t%u\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\t%.5g\n",
+	     countVoxelsUnequal, maxDifference, maxRelDifference, sumSq / voxelCount, sumAbs / voxelCount, ccMetric.Get(), hXY, hX + hY - hXY, ( hX + hY ) / hXY );
+    }
+  
+  if ( !HistogramTextFileName.empty() )
+    {
+    FILE *file = fopen( HistogramTextFileName.c_str(), "w" );
     if ( file ) 
       {
       unsigned int binsX = histogram->GetNumBinsX();
@@ -362,8 +376,12 @@ doMain ( const int argc, const char* argv[] )
 
 	const unsigned int totalRefFlt = totalRef + totalFlt - correct;
 	const double J = static_cast<double>( 1.0 * correct / totalRefFlt ); // Jaccard index
-	fprintf( stdout, "\n%06d\t%d\t%d\t%.5lf\t%d\t%.5lf\t%d\t%.5lf\t%.5lf\t%.5lf", 
-		 i, totalRef, correct, 1.0 * correct / totalRef, falseNeg, 1.0 * falseNeg / totalRef, falsePos, 1.0 * falsePos / totalRef, SI, J );
+
+	if ( totalRef )
+	  {
+	  fprintf( stdout, "\n%06u\t%u\t%u\t%.5lf\t%u\t%.5lf\t%u\t%.5lf\t%.5lf\t%.5lf", 
+		   i, totalRef, correct, 1.0 * correct / totalRef, falseNeg, 1.0 * falseNeg / totalRef, falsePos, 1.0 * falsePos / totalRef, SI, J );
+	  }
 	
 	if ( i )
 	  { // assume background is label #0 and exclude this
@@ -378,13 +396,16 @@ doMain ( const int argc, const char* argv[] )
 	{
 	// this label does not exist in the reference image
 	if ( i <= ForceMaxLabel ) 
-	  fprintf( stdout, "\nLabel #%d\t<n/a>", i );
+	  fprintf( stdout, "\nLabel #%u\t<n/a>", i );
 	}
       }
     avgRecog /= (countLabels+1);
     
     fputs( "\n\n\tsumTot\tsumCorr\t%corr\tavgSI\tWmeanSI\n", stdout );
-    fprintf( stdout, "Total:\t%d\t%d\t%.2lf\t%.4lf\t%.4lf\n\n", sumTotal, sumCorrect, 100.0 * sumCorrect / sumTotal, sumSI / countLabels, sumSIweighted / sumTotal );
+    if ( sumTotal && countLabels )
+      {
+      fprintf( stdout, "Total:\t%u\t%u\t%.2lf\t%.4lf\t%.4lf\n\n", sumTotal, sumCorrect, 100.0 * sumCorrect / sumTotal, sumSI / countLabels, sumSIweighted / sumTotal );
+      }
     fprintf( stdout, "AvgRecog:\t%.6f\n", avgRecog );
     }
 
