@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4447 $
+//  $Revision: 5021 $
 //
-//  $LastChangedDate: 2012-07-06 13:51:04 -0700 (Fri, 06 Jul 2012) $
+//  $LastChangedDate: 2013-11-23 09:17:13 -0800 (Sat, 23 Nov 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -163,6 +163,10 @@ doMain( const int argc, const char* argv[] )
   cmtk::AffineXform::MatrixType xformMatrix = volumes[0]->GetImageToPhysicalMatrix();
   // and copy to output
   stacked->m_IndexToPhysicalMatrix *= xformMatrix;
+  for ( std::map<int,cmtk::AffineXform::MatrixType>::iterator it = stacked->m_AlternativeIndexToPhysicalMatrices.begin(); it != stacked->m_AlternativeIndexToPhysicalMatrices.end(); ++it )
+    {
+    it->second *= xformMatrix;
+    }
   stacked->CopyMetaInfo( *(volumes[0]) );
   
   if ( outputFilePath )
