@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2010 SRI International
+//  Copyright 2004-2010, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4236 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -32,6 +32,8 @@
 
 #include "cmtkAnatomicalOrientation.h"
 
+#include <System/cmtkExitException.h>
+
 #include <string>
 #include <iostream>
 
@@ -88,7 +90,15 @@ AnatomicalOrientation::PermutationMatrix::GetMatrix() const
     permutation[3][j] = this->m_Offsets[j];
     }
 
-  return permutation.GetInverse();
+  try
+    {
+    return permutation.GetInverse();
+    }
+  catch ( const AffineXform::MatrixType::SingularMatrixException& )
+    {
+    StdErr << "ERROR: orientation permutation matrix connot be inverted.\n";
+    throw ExitException( 1 );
+    }
 }
 
 AffineXform::MatrixType
