@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5083 $
+//  $Revision: 5235 $
 //
-//  $LastChangedDate: 2013-12-03 15:22:05 -0800 (Tue, 03 Dec 2013) $
+//  $LastChangedDate: 2014-03-18 11:33:22 -0700 (Tue, 18 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -243,6 +243,8 @@ DataGrid::GetReoriented( const char* newOrientation ) const
       {
       newData->SetPaddingValue( oldData->GetPaddingValue() );
       }
+
+    newData->SetDataClass( oldData->GetDataClass() );
     
     const char* fromPtr = static_cast<const char*>( oldData->GetDataPtr() );
     char* toPtr = static_cast<char*>( newData->GetDataPtr() );
