@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4897 $
+//  $Revision: 5222 $
 //
-//  $LastChangedDate: 2013-09-30 14:12:06 -0700 (Mon, 30 Sep 2013) $
+//  $LastChangedDate: 2014-03-10 11:11:12 -0700 (Mon, 10 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -34,6 +34,7 @@
 
 #include <System/cmtkException.h>
 #include <System/cmtkThreadPool.h>
+#include <System/cmtkProgress.h>
 
 #include <Base/cmtkRegionIndexIterator.h>
 #include <Base/cmtkMathFunctionWrappers.h>
