@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2012, 2013 SRI International
+//  Copyright 2012-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4882 $
+//  $Revision: 5355 $
 //
-//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
+//  $LastChangedDate: 2014-05-09 16:55:27 -0700 (Fri, 09 May 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -65,7 +65,7 @@ public:
 
   /// Constructor.
   DetectedPhantomMagphanEMR051( const AffineXform& linearFitXform /*!< Fitted linear (including shear and scale) transformation */ ) : 
-    m_EstimatedSNR( 0.0 ), m_LinearFitXform( linearFitXform ) {}
+    m_EstimatedSNR( 0.0 ), m_MaxDimming( 0.0 ), m_LinearFitXform( linearFitXform ) {}
     
     
   /// Add expected and actual location of a detected phantom landmark.
@@ -97,9 +97,12 @@ public:
     return this->m_LandmarkPairs;
   }
       
-  /// Estimated image signal-to-noise ratio..
+  /// Estimated image signal-to-noise ratio.
   Types::DataItem m_EstimatedSNR;
 
+  /// Estimated maximum dimming (i.e., minimum fraction of intensity of a 10mm sphere relative to maximum)
+  Types::DataItem m_MaxDimming;
+
   /// Estimated image contrast-to-noise ratio.
   FixedVector<4,Types::DataItem> m_EstimatedCNR;
 
