@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4236 $
+//  $Revision: 4430 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 13:55:02 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -31,6 +31,7 @@
 #include "cmtkFitAffineToWarpXform.h"
 
 #include <Base/cmtkRegionIndexIterator.h>
+#include <Base/cmtkMathUtil.h>
 
 #include <System/cmtkDebugOutput.h>
 
@@ -45,18 +46,23 @@ cmtk::FitAffineToWarpXform::Fit()
   const WarpXform& warpXform = *(this->m_WarpXform); // bypass smart pointer for speed
   
   // first, get the centroids in "from" and "to" space
-  cmtk::FixedVector<3,cmtk::Types::Coordinate> cFrom( cmtk::FixedVector<3,cmtk::Types::Coordinate>::Init( 0 ) );
-  cmtk::FixedVector<3,cmtk::Types::Coordinate> cTo( cmtk::FixedVector<3,cmtk::Types::Coordinate>::Init( 0 ) );
+  cmtk::FixedVector<3,cmtk::Types::Coordinate> cFrom( 0.0 );
+  cmtk::FixedVector<3,cmtk::Types::Coordinate> cTo( 0.0 );
   
+  size_t valid = 0;
   for ( RegionIndexIterator<WarpXform::ControlPointRegionType> it = warpXform.GetInsideControlPointsRegion(); it != it.end(); ++it )
     {
-    cFrom += warpXform.GetOriginalControlPointPosition( it.Index()[0], it.Index()[1], it.Index()[2] );
-    cTo += warpXform.GetDeformedControlPointPosition( it.Index()[0], it.Index()[1], it.Index()[2] );
+    const WarpXform::SpaceVectorType v = warpXform.GetDeformedControlPointPosition( it.Index()[0], it.Index()[1], it.Index()[2] );
+    if ( MathUtil::IsFinite( v[0] ) )
+      {
+      ++valid;
+      cFrom += warpXform.GetOriginalControlPointPosition( it.Index()[0], it.Index()[1], it.Index()[2] );
+      cTo += v;
+      }
     }
   
-  const size_t size = warpXform.GetInsideControlPointsRegion().Size();
-  cFrom /= size;
-  cTo /= size;
+  cFrom /= valid;
+  cTo /= valid;
 
   // now get the transformation matrix for rotation, scale, shear, using the previously computed centroids for reference
   Matrix3x3<Types::Coordinate> matrix = Self::GetMatrix( *(this->m_WarpXform), cFrom, cTo );
@@ -82,12 +88,15 @@ cmtk::FitAffineToWarpXform::GetMatrix( const WarpXform& warpXform, const cmtk::F
     const cmtk::FixedVector<3,cmtk::Types::Coordinate> x = warpXform.GetOriginalControlPointPosition( it.Index()[0], it.Index()[1], it.Index()[2] ) - cFrom;
     const cmtk::FixedVector<3,cmtk::Types::Coordinate> t = warpXform.GetDeformedControlPointPosition( it.Index()[0], it.Index()[1], it.Index()[2] ) - cTo;
 
-    for ( size_t j = 0; j < 3; ++j )
+    if ( MathUtil::IsFinite( t[0] ) )
       {
-      for ( size_t i = 0; i < 3; ++i )
+      for ( size_t j = 0; j < 3; ++j )
 	{
-	txT[i][j] += t[j] * x[i];
-	xxT[i][j] += x[j] * x[i];
+	for ( size_t i = 0; i < 3; ++i )
+	  {
+	  txT[i][j] += t[j] * x[i];
+	  xxT[i][j] += x[j] * x[i];
+	  }
 	}
       }
     }  
