@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 2735 $
+//  $Revision: 4441 $
 //
-//  $LastChangedDate: 2011-01-14 10:34:12 -0800 (Fri, 14 Jan 2011) $
+//  $LastChangedDate: 2012-06-18 11:02:46 -0700 (Mon, 18 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -58,8 +58,11 @@ class ImageTemplate :
   public UniformVolume 
 {
 public:
+  /// Pixel data type.
+  typedef TPixelType PixelType;
+
   /// This class.
-  typedef ImageTemplate Self;
+  typedef ImageTemplate<TPixelType> Self;
 
   /// Superclass.
   typedef UniformVolume Superclass;
@@ -70,9 +73,6 @@ public:
   /// Smart pointer to const ImageTemplate.
   typedef SmartConstPointer<Self> SmartConstPtr;
 
-  /// Pixel data type.
-  typedef TPixelType PixelType;
-
   /// Region type.
   typedef Superclass::CoordinateRegionType CoordinateRegionType;
 
@@ -86,9 +86,18 @@ public:
    *\param dims Number of grid elements for the three spatial dimensions.
    *\param size Size of the volume in real-world coordinates.
    */
-  ImageTemplate( const DataGrid::IndexType& dims, const Self::CoordinateVectorType& size ) : Superclass( dims, size ) 
+  ImageTemplate( const DataGrid::IndexType& dims, const typename Self::CoordinateVectorType& size ) : Superclass( dims, size ) 
   {
-    this->m_DataArray.resize( this->GetNumberOfPixels );
+    this->m_DataArray.resize( this->GetNumberOfPixels() );
+  }
+
+  /** Create volume from base class instance.
+   *\param dims Number of grid elements for the three spatial dimensions.
+   *\param size Size of the volume in real-world coordinates.
+   */
+  ImageTemplate( const Superclass& from ) : Superclass( from ) 
+  {
+    this->m_DataArray.resize( this->GetNumberOfPixels() );
   }
 
   /// Access operator.
@@ -112,6 +121,4 @@ private:
 
 } // namespace cmtk
 
-#include "cmtkImageTemplate.txx"
-
 #endif // #ifndef __cmtkImageTemplate_h_included_
