@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5054 $
+//  $Revision: 5160 $
 //
-//  $LastChangedDate: 2013-12-01 16:08:07 -0800 (Sun, 01 Dec 2013) $
+//  $LastChangedDate: 2014-01-12 14:33:52 -0800 (Sun, 12 Jan 2014) $
 //
-//  $LastChangedBy: jefferis $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -64,6 +64,21 @@ Matrix4x4<T>::Matrix4x4( const Matrix3x3<T>& other )
   this->m_Matrix[3][3] = 1.0;
 }
 
+template<class T>
+const Matrix3x3<T> 
+Matrix4x4<T>::GetTopLeft3x3() const
+{
+  Matrix3x3<T> m3;
+  for ( int j=0; j<3; ++j ) 
+    {
+    for ( int i=0; i<3; ++i ) 
+      {
+      m3[i][j] = this->m_Matrix[i][j];
+      }
+    }
+  return m3;
+}
+
 template<class T>
 Matrix4x4<T>&
 Matrix4x4<T>::Compose
