@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3799 $
+//  $Revision: 4105 $
 //
-//  $LastChangedDate: 2012-02-02 14:44:21 -0800 (Thu, 02 Feb 2012) $
+//  $LastChangedDate: 2012-03-30 13:47:57 -0700 (Fri, 30 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -112,6 +112,12 @@ public:
     return size;
   }
 
+  /// Check if an index is inside region.
+  bool IsInside( const typename Self::IndexType idx ) const
+  {
+    return (this->m_RegionFrom <= idx) && (idx < this->m_RegionTo);
+  }
+  
   /// Get one face of the region, as a region
   const Self GetFaceRegion( const int dim /*!< Returned face is orthogonal to this index dimension */, const bool upper = false /*!< If true, upper face is returned, otherwise lower face.*/ ) const;
   
