@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4538 $
+//  $Revision: 4870 $
 //
-//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
+//  $LastChangedDate: 2013-09-24 11:01:11 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -53,6 +53,7 @@ SplineWarpXform::SplineWarpXform()
 void SplineWarpXform::Init () 
 {
   this->m_GlobalScaling = 1.0;
+  memset( this->GridPointOffset, 0, sizeof( this->GridPointOffset ) );
 }
 
 SplineWarpXform::SplineWarpXform 
@@ -598,11 +599,10 @@ SplineWarpXform::GetTransformedGridRow
   std::vector<Types::Coordinate> phiHat( 3*numberOfCells );
 #endif
 
-  const int *gpo;
   int phiIdx = 0;
   for ( int cell = 0; cell < numberOfCells; ++cell, coeff += nextI ) 
     {
-    gpo = &this->GridPointOffset[0];
+    const int *gpo = &this->GridPointOffset[0];
     for ( int dim = 0; dim < 3; ++dim, ++phiIdx ) 
       {
       phiComp = coeff[ *gpo ] * sml[0];
