@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3735 $
+//  $Revision: 4870 $
 //
-//  $LastChangedDate: 2012-01-25 12:36:34 -0800 (Wed, 25 Jan 2012) $
+//  $LastChangedDate: 2013-09-24 11:01:11 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -147,11 +147,10 @@ cmtk::SplineWarpXformUniformVolume::GetTransformedGridRow
   Types::Coordinate phiComp;
   std::vector<Types::Coordinate> phiHat( 3*numberOfCells );
 
-  const int *gpo;
   int phiIdx = 0;
   for ( int cell = 0; cell < numberOfCells; ++cell, coeff += xform.nextI ) 
     {
-    gpo = &this->GridPointOffset[0];
+    const int *gpo = &this->GridPointOffset[0];
     for ( int dim = 0; dim < 3; ++dim, ++phiIdx ) 
       {
       phiComp = coeff[ *gpo ] * sml[0];
