@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 1997-2009 Torsten Rohlfing
+//  Copyright 1997-2012 Torsten Rohlfing
 //
 //  Copyright 2004-2012 SRI International
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3735 $
+//  $Revision: 4275 $
 //
-//  $LastChangedDate: 2012-01-25 12:36:34 -0800 (Wed, 25 Jan 2012) $
+//  $LastChangedDate: 2012-04-29 12:39:40 -0700 (Sun, 29 Apr 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -43,26 +43,6 @@ cmtk
 /** \addtogroup Base */
 //@{
 
-Types::Coordinate
-SplineWarpXform::GetRigidityConstraintSparse () const
-{
-  double Constraint = 0;
-  CoordinateMatrix3x3 J;
-
-  const Types::Coordinate* coeff = this->m_Parameters + nextI + nextJ + nextK;
-  for ( int z = 1; z<this->m_Dims[2]-1; ++z, coeff+=2*nextJ )
-    for ( int y = 1; y<this->m_Dims[1]-1; ++y, coeff+=2*nextI )
-      for ( int x = 1; x<this->m_Dims[0]-1; ++x, coeff+=nextI )
-	{
-	this->GetJacobian( Self::SpaceVectorType( coeff ), J );
-	Constraint += this->GetRigidityConstraint( J );
-	}
-  
-  // Divide by number of control points to normalize with respect to the
-  // number of local Jacobians in the computation.
-  return (Types::Coordinate)(Constraint / this->m_NumberOfControlPoints);
-}
-
 void 
 SplineWarpXform::GetRigidityConstraintDerivative
 ( double& lower, double& upper, const int param, const DataGrid::RegionType& voi, const Types::Coordinate step ) const
@@ -189,13 +169,11 @@ SplineWarpXform::GetRigidityConstraintDerivative
   const int jTo = std::min( 1, this->m_Dims[1]-2-y );
   const int kTo = std::min( 1, this->m_Dims[2]-2-z );
 
-  CoordinateMatrix3x3 J;
   for ( int k = kFrom; k < kTo; ++k )
     for ( int j = jFrom; j < jTo; ++j )
       for ( int i = iFrom; i < iTo; ++i )
 	{
-	this->GetJacobianAtControlPoint( coeff + i*nextI + j*nextJ + k*nextK, J );
-	ground += this->GetRigidityConstraint( J );
+	ground += this->GetRigidityConstraint( this->GetJacobianAtControlPoint( coeff + i*nextI + j*nextJ + k*nextK ) );
 	}
   
   upper = -ground;
@@ -207,8 +185,7 @@ SplineWarpXform::GetRigidityConstraintDerivative
     for ( int j = jFrom; j < jTo; ++j )
       for ( int i = iFrom; i < iTo; ++i )
 	{
-	this->GetJacobianAtControlPoint( coeff + i*nextI + j*nextJ + k*nextK, J );
-	upper += this->GetRigidityConstraint( J );
+	upper += this->GetRigidityConstraint( this->GetJacobianAtControlPoint( coeff + i*nextI + j*nextJ + k*nextK ) );
 	}
 
   this->m_Parameters[param] = oldCoeff - step;
@@ -216,8 +193,7 @@ SplineWarpXform::GetRigidityConstraintDerivative
     for ( int j = jFrom; j < jTo; ++j )
       for ( int i = iFrom; i < iTo; ++i )
 	{
-	this->GetJacobianAtControlPoint( coeff + i*nextI + j*nextJ + k*nextK, J );
-	lower += this->GetRigidityConstraint( J );
+	lower += this->GetRigidityConstraint( this->GetJacobianAtControlPoint( coeff + i*nextI + j*nextJ + k*nextK ) );
 	}
   this->m_Parameters[param] = oldCoeff;
 
@@ -273,14 +249,7 @@ Types::Coordinate
 SplineWarpXform::GetRigidityConstraint( const CoordinateMatrix3x3& J ) 
   const
 {
-  Matrix2D<Types::Coordinate> matrix2d( 3, 3 );
-  for ( int i = 0; i < 3; ++i )
-    for ( int j = 0; j < 3; ++j )
-      matrix2d[i][j] = J[i][j];
-
-  QRDecomposition<Types::Coordinate> qr( matrix2d );
-  const Matrix2D<Types::Coordinate> R = qr.GetR();
-  
+  const Matrix2D<Types::Coordinate> R = QRDecomposition<Types::Coordinate>( J ).GetR();  
   return MathUtil::Square( R[0][1] / R[0][0] ) + MathUtil::Square( R[0][2] / R[0][0] ) + MathUtil::Square( R[1][2] / R[1][1] );
 }
 
