@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4106 $
+//  $Revision: 4998 $
 //
-//  $LastChangedDate: 2012-03-30 13:48:41 -0700 (Fri, 30 Mar 2012) $
+//  $LastChangedDate: 2013-10-21 12:09:23 -0700 (Mon, 21 Oct 2013) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -307,13 +307,7 @@ public:
   }
   
   /// Default constructor.
-  TypedArray () 
-  {
-    DataSize = 0;
-    PaddingFlag = false;
-    this->m_Deallocator = NULL;
-    this->m_DataClass = DATACLASS_GREY;
-  }
+  TypedArray () : m_DataClass( DATACLASS_GREY ), m_DataType( TYPE_NONE ), m_Deallocator( NULL ), DataSize( 0 ), PaddingFlag( false ) {}
   
   /** Destructor.
    * Just has to be declared virtual.
@@ -472,6 +466,21 @@ public:
     this->ConvertSubArray( target.GetDataPtr( toOffset ), target.GetType(), fromOffset, blockLength );
   }
 
+  /// Exception class for array size mismatched.
+  class SizeMismatchException : public Exception {};
+
+  /** Copy other array.
+   * This is a convenience wrapper for ConvertSubArray().
+   */
+  virtual void Copy( const Self& other )
+  {
+    if ( this->GetDataSize() != other.GetDataSize() )
+      {
+      throw SizeMismatchException();
+      }
+    other.ConvertSubArray( this->GetDataPtr(), this->GetType(), 0, this->GetDataSize() );
+  }
+
   /** Exchange two data blocks.
    * Internally, the data is copied in chunks of up to 2KB (currently), using
    * an 'automatic' intermediate buffer of that size.
