@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5021 $
+//  $Revision: 5245 $
 //
-//  $LastChangedDate: 2013-11-23 09:17:13 -0800 (Sat, 23 Nov 2013) $
+//  $LastChangedDate: 2014-03-18 15:43:47 -0700 (Tue, 18 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -70,50 +70,6 @@ UniformVolume::UniformVolume
   this->CreateDefaultIndexToPhysicalMatrix();
 }
 
-UniformVolume* 
-UniformVolume::GetResampled
-( const Types::Coordinate resolution, const bool allowUpsampling ) const
-{
-  Self::IndexType newDims;
-  Self::SpaceVectorType newSize;
-  Self::SpaceVectorType newDelta;
-
-  for ( int dim=0; dim<3; ++dim ) 
-    {
-    newSize[dim] = this->m_Size[dim];
-    const int new_dims=(int) (newSize[dim]/resolution)+1;
-    if ( allowUpsampling || (new_dims<=this->m_Dims[dim]) ) 
-      {
-      newDims[dim]=new_dims;
-      newDelta[dim] = newSize[dim]/(new_dims-1);
-      } 
-    else
-      {
-      if ( this->m_Dims[dim] == 1 ) 
-	{
-	newDelta[dim] = newSize[dim];
-	newDims[dim] = 1;
-	} 
-      else 
-	{
-	newDelta[dim] = this->m_Delta[dim];
-	newDims[dim] = ((int)(newSize[dim]/newDelta[dim])) + 1;
-	newSize[dim] = (newDims[dim]-1) * newDelta[dim];
-	}
-      }
-    }
-
-  UniformVolume* newVolume = new UniformVolume( newDims, newSize );
-  newVolume->SetData( TypedArray::SmartPtr( newVolume->Resample( *this ) ) );
-  
-  newVolume->SetImageToPhysicalMatrix( this->GetImageToPhysicalMatrix() );
-  newVolume->SetHighResCropRegion( this->GetHighResCropRegion() );
-  newVolume->SetOffset( this->m_Offset );
-  newVolume->CopyMetaInfo( *this );
-
-  return newVolume;
-}
-
 UniformVolume*
 UniformVolume::CloneVirtual( const bool copyData )
 {
