@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5021 $
+//  $Revision: 5242 $
 //
-//  $LastChangedDate: 2013-11-23 09:17:13 -0800 (Sat, 23 Nov 2013) $
+//  $LastChangedDate: 2014-03-18 15:34:46 -0700 (Tue, 18 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -132,6 +132,13 @@ public:
    */
   virtual UniformVolume* GetResampled( const Types::Coordinate resolution, const bool allowUpsampling = false ) const;
 
+  /** Resample volume to an exact given resolution.
+   * Unlike GetResampled(), this function forces the pixel size of the resampled image to be exactly the given "resolution." Grid dimensions and volume size are adjusted accordingly.
+   *\param resolution Resolution of the newly created volume in world units.
+   *\return Newly created, resampled volume.
+   */
+  virtual UniformVolume* GetResampledExact( const Types::Coordinate resolution ) const;
+
   /** Coordinate transformation from index to physical position.
    * This incorporates image axis directions and first pixel offset.
    *\note Strictly, this is not a transformation from the pixel index
