@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 2398 $
+//  $Revision: 4746 $
 //
-//  $LastChangedDate: 2010-10-05 14:54:37 -0700 (Tue, 05 Oct 2010) $
+//  $LastChangedDate: 2013-05-14 21:09:18 -0700 (Tue, 14 May 2013) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -48,6 +48,15 @@ cmtk
 /// Convenience typedef: vectors in 3D coordinate space.
 typedef FixedVector<3,Types::Coordinate> Vector3D;
 
+/// Cross-product of two 3D vectors.
+template<class T>
+FixedVector<3,T> 
+CrossProduct( const FixedVector<3,T>& u, const FixedVector<3,T>& v )
+{
+  const T result[3] = { u[1]*v[2] - u[2]*v[1], u[2]*v[0] - u[0]*v[2], u[0]*v[1] - u[1]*v[0] };
+  return FixedVector<3,T>::FromPointer( result );
+}
+
 //@}
 
 } // namespace cmtk
