@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4882 $
+//  $Revision: 5160 $
 //
-//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
+//  $LastChangedDate: 2014-01-12 14:33:52 -0800 (Sun, 12 Jan 2014) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -210,6 +210,16 @@ public:
       ( v[1] >= 0 ) && ( v[1] <= this->m_Domain[1] ) &&
       ( v[2] >= 0 ) && ( v[2] <= this->m_Domain[2] );
   }
+
+  /** Project coordinate to domain of transformation.
+   */
+  virtual void ProjectToDomain( Self::SpaceVectorType& v ) const
+  {
+    for ( int dim = 0; dim < 3; ++dim )
+      {
+      v[dim] = std::max<Types::Coordinate>( 0, std::min<Types::Coordinate>( v[dim], this->m_Domain[dim] ) );
+      }
+  }
   
   /// Update internal representation.
   virtual void Update( const bool exactDelta = false );
