@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3981 $
+//  $Revision: 4381 $
 //
-//  $LastChangedDate: 2012-03-06 16:10:33 -0800 (Tue, 06 Mar 2012) $
+//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -86,7 +86,7 @@ ImageSymmetryPlaneFunctionalDevice::Evaluate()
     {
     for ( size_t i = 0; i < 3; ++i )
       {
-      matrix[j][i] /= static_cast<float>( this->m_Volume->Size[i] );
+      matrix[j][i] /= static_cast<float>( this->m_Volume->m_Size[i] );
       }
     }
   
