@@ -22,25 +22,23 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3713 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-01-10 15:33:21 -0800 (Tue, 10 Jan 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
 */
 
-#include "cmtkClassStream.h"
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 
 namespace
 cmtk
 {
 
-/** \addtogroup IO */
-//@{
-
-ClassStream& 
-ClassStream::operator>>( ParametricPlane*& parametricPlane )
+ClassStreamInput& 
+ClassStreamInput::operator>>( ParametricPlane*& parametricPlane )
 {
   parametricPlane = NULL;
 
@@ -51,7 +49,7 @@ ClassStream::operator>>( ParametricPlane*& parametricPlane )
 
   Types::Coordinate planeOrigin[3];
   this->ReadCoordinateArray( "origin", planeOrigin, 3 );
-  parametricPlane->SetOrigin( FixedVector<3,Types::Coordinate>( planeOrigin ) );
+  parametricPlane->SetOrigin( FixedVector<3,Types::Coordinate>::FromPointer( planeOrigin ) );
 
   parametricPlane->SetRho( this->ReadCoordinate( "rho" ) );
   parametricPlane->SetTheta( Units::Degrees( this->ReadCoordinate( "theta" ) ) );
@@ -60,8 +58,8 @@ ClassStream::operator>>( ParametricPlane*& parametricPlane )
   return *this;
 }
 
-ClassStream&
-ClassStream::operator<<( const ParametricPlane* parametricPlane )
+ClassStreamOutput&
+ClassStreamOutput::operator<<( const ParametricPlane* parametricPlane )
 {  
   this->Begin( "plane" );
   this->WriteCoordinateArray( "origin", parametricPlane->GetOrigin().begin(), 3 );
