@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5098 $
+//  $Revision: 5347 $
 //
-//  $LastChangedDate: 2013-12-20 13:25:14 -0800 (Fri, 20 Dec 2013) $
+//  $LastChangedDate: 2014-05-01 15:26:43 -0700 (Thu, 01 May 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -450,12 +450,14 @@ DICOM::ParseSiemensCSA( const DcmTagKey& tagKey, int& unmosaicImageCols, int& un
 	      }
 	    else
 	      {
-	      StdErr << "ERROR: unable to get image origin component from: " << it->second[0] << " in file " << this->m_Path << "\n";
+	      StdErr << "ERROR: unable to get image origin component from: " << it->second[0] << " in file " << this->m_Path << "\nAssuming zero.\n";
+	      imageOrigin[i] = 0;
 	      }
 	    }
 	  else
 	    {
-	    StdErr << "ERROR: unable to get image origin tag for component " <<  sliceOrientationString[i] << " from CSA header in file " << this->m_Path << "\n";
+	    StdErr << "ERROR: unable to get image origin tag for component " <<  sliceOrientationString[i] << " from CSA header in file " << this->m_Path << "\nAssuming zero.\n";
+	    imageOrigin[i] = 0;	    
 	    }
 	}
       }
