@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
@@ -110,8 +110,10 @@ ImageFileDICOM::ImageFileDICOM( const std::string& filepath )
   :m_IsMultislice( false ),
    m_IsDWI( false ),   
    m_DwellTime( 0.0 ),
+   m_PhaseEncodeDirectionSign( "" ),
    m_BValue( 0 ),
    m_BVector( 0.0 ),
+   m_HasBVector( false ),
    m_RawDataType( "unknown" )
 {
   if ( cmtk::FileFormat::Identify( filepath, false /*decompress*/ ) != cmtk::FILEFORMAT_DICOM ) // need to disable "decompress" in Identify() because DCMTK cannot currently read using on-the-fly decompression.
@@ -174,12 +176,18 @@ ImageFileDICOM::ImageFileDICOM( const std::string& filepath )
   // read the string tags that we need for later
   const DcmTagKey defaultStringTags[] = { DCM_Manufacturer, DCM_ManufacturerModelName, DCM_DeviceSerialNumber, DCM_StationName, DCM_AcquisitionTime,
 					  DCM_PatientsName, 
-					  DCM_Modality, DCM_EchoTime, DCM_RepetitionTime, DCM_InversionTime, DCM_ImagingFrequency, DCM_SequenceName,
-					  DCM_GE_PulseSequenceName, DCM_GE_PulseSequenceDate, DCM_GE_InternalPulseSequenceName, DCM_GE_AssetRFactors,
+					  DCM_Modality, DCM_EchoTime, DCM_RepetitionTime, DCM_InversionTime, DCM_ImagingFrequency, DCM_SequenceName, DCM_InPlanePhaseEncodingDirection,
 					  DCM_StudyInstanceUID, DCM_StudyID, DCM_StudyDate,
 					  DCM_FrameOfReferenceUID, DCM_SeriesInstanceUID, DCM_SeriesDescription,
 					  DCM_ImagePositionPatient, DCM_ImageOrientationPatient, 
 					  DCM_RescaleIntercept, DCM_RescaleSlope,
+					  // GE-specific tags
+					  DCM_GE_PulseSequenceName, DCM_GE_PulseSequenceDate, DCM_GE_InternalPulseSequenceName, DCM_GE_AssetRFactors,
+					  // Siemens-specific tags
+
+					  // Philips-specific tags
+
+					  // Zero-tag ends the array
 					  DcmTagKey( 0, 0 ) };
   
   for ( size_t tagIdx = 0; (defaultStringTags[tagIdx].getGroup() != 0) && (defaultStringTags[tagIdx].getElement() != 0); ++tagIdx )
@@ -213,17 +221,30 @@ ImageFileDICOM::ImageFileDICOM( const std::string& filepath )
     {
     this->DoVendorTagsGE();
     }
+
+  if ( this->m_TagToStringMap[DCM_Manufacturer].substr( 0, 7 ) == "Philips" )
+    {
+    this->DoVendorTagsPhilips();
+    }
 }
 
 void
 ImageFileDICOM::DoVendorTagsSiemens()
 {
   Uint16 nFrames = 0;
+  double tmpDbl = 0;
   const char* tmpStr = NULL;
 
   this->m_IsMultislice = (0 != this->m_Document->getValue( DcmTagKey (0x0019,0x100a), nFrames )); // Number of Slices tag
   this->m_IsMultislice |= ( this->m_Document->getValue( DCM_ImageType, tmpStr ) && strstr( tmpStr, "MOSAIC" ) ); // mosaics are always multi-slice
-  
+
+  // Retrieve slice times if this tag exists (it's an array of double-precision floats)
+  for ( size_t slice = 0, nslices = this->m_Document->getVM( DCM_Siemens_MosaicRefAcqTimes ); slice < nslices; ++slice )
+    {
+    if ( this->m_Document->getValue( DCM_Siemens_MosaicRefAcqTimes, tmpDbl, slice ) > 0 )
+      this->m_SliceTimes.push_back( tmpDbl );
+    }
+
   if ( this->GetTagValue( DCM_Modality ) == "MR" )
     {
     // try to extract raw data type from "ImageType"
@@ -252,14 +273,31 @@ ImageFileDICOM::DoVendorTagsSiemens()
 	{
 	this->m_DwellTime = 0.0;
 	}
-      }
 
+      it = csaImageHeader.find( "PhaseEncodingDirectionPositive" );
+      if ( (it != csaImageHeader.end()) && !it->second.empty() )
+	{
+	switch ( it->second[0][0] )
+	  {
+	  case '0':
+	    this->m_PhaseEncodeDirectionSign = "NEG";
+	    break;
+	  case '1':
+	    this->m_PhaseEncodeDirectionSign = "POS";
+	    break;
+	  default:
+	    this->m_PhaseEncodeDirectionSign = "UNKNOWN";	    
+	    break;
+	  }
+	}
+      }
+      
     // for DWI, first check standard DICOM vendor tags
     if ( (this->m_IsDWI = (this->m_Document->getValue( DcmTagKey(0x0019,0x100d), tmpStr )!=0)) ) // "Directionality" tag
       {
       if ( this->m_Document->getValue( DcmTagKey(0x0019,0x100c), tmpStr ) != 0 ) // bValue tag
 	{
-	this->m_BValue = atoi( tmpStr );
+	this->m_BValue = atof( tmpStr );
 	this->m_IsDWI |= (this->m_BValue > 0);
 	}
       
@@ -299,6 +337,7 @@ ImageFileDICOM::DoVendorTagsSiemens()
 	  }
 	}
       }
+    this->m_HasBVector = this->m_IsDWI;
     }
 }
 
@@ -306,6 +345,7 @@ void
 ImageFileDICOM::DoVendorTagsGE()
 {
   int tmpInt = 0;
+  double tmpDbl = 0;
 
   if ( this->GetTagValue( DCM_Modality ) == "MR" )
     {
@@ -355,8 +395,9 @@ ImageFileDICOM::DoVendorTagsGE()
 	  {
 	  if ( 1 == sscanf( tmpStr, "%10d\\%*c", &tmpInt ) )
 	    {
-	    this->m_BValue = static_cast<Sint16>( tmpInt );
+	    this->m_BValue = static_cast<double>( tmpInt );
 
+	    this->m_HasBVector = true;
 	    for ( int i = 0; i < 3; ++i )
 	      {
 	      if ( this->m_Document->getValue( DcmTagKey(0x0019,0x10bb+i), tmpStr ) > 0 ) // bVector tags
@@ -366,6 +407,7 @@ ImageFileDICOM::DoVendorTagsGE()
 	      else
 		{
 		this->m_BVector[i] = 0;
+		this->m_HasBVector = false;
 		}
 	      }
 	    this->m_BVector[2] *= -1; // for some reason z component apparently requires negation of sign on GE
@@ -376,6 +418,42 @@ ImageFileDICOM::DoVendorTagsGE()
     }
 }
 
+void
+ImageFileDICOM::DoVendorTagsPhilips()
+{
+  double tmpDbl = 0;
+
+  if ( this->GetTagValue( DCM_Modality ) == "MR" )
+    {
+    if ( this->m_Document->getValue( DcmTagKey(0x0018,0x9087), tmpDbl ) > 0 ) // bValue tag
+      {
+      this->m_IsDWI = true;
+      this->m_BValue = tmpDbl;
+      }
+
+    this->m_HasBVector = true;
+    if ( this->m_BValue > 0 )
+      {
+      for ( size_t i = 0; this->m_IsDWI && (i < 3); ++i )
+	{
+	if ( this->m_Document->getValue( DcmTagKey(0x0018,0x9089), tmpDbl, i ) > 0 )
+	  this->m_BVector[i] = tmpDbl;
+	else
+	  this->m_IsDWI = false;
+	}
+
+      const char* tmpStr = NULL;
+      if ( this->m_Document->getValue( DcmTagKey(0x2001,0x1004), tmpStr ) > 0 ) // DiffusionDirection tag - "O", oblique or "I", isotropic. Uses "I" with bValue!=0 to identify average diffusion image
+	{
+	if ( tmpStr )
+	  {
+	  this->m_HasBVector = (tmpStr[0] != 'I');
+	  }
+	}
+      }
+    }
+}
+
 bool
 ImageFileDICOM::MatchAnyPattern( const std::map<DcmTagKey,std::string>& patterns ) const
 {
