@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3750 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-01-26 13:59:12 -0800 (Thu, 26 Jan 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -68,7 +68,7 @@ cmtk::SplineWarpXformITKIO
       {
       v = xform.GetOriginalControlPointPositionByOffset( cp );
       if ( bulkXform )
-	bulkXform->ApplyInPlace( v );
+	v = bulkXform->Apply( v );
       vx = xform.GetShiftedControlPointPositionByOffset( cp );
 
       vx -= v;
