@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4341 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-05-11 11:33:49 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -112,9 +112,6 @@ public:
 	return NULL;
   }
   
-  /// Create studylist archive.
-  static void Write( const char *path, const char* referenceStudy, const char* floatingStudy, const Xform* xform );
-
 private:
   /// The names of the two studies referenced in the studylist.
   char *StudyPath[2];
