@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2011 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2012, 2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5078 $
+//  $Revision: 5319 $
 //
-//  $LastChangedDate: 2013-12-02 16:26:25 -0800 (Mon, 02 Dec 2013) $
+//  $LastChangedDate: 2014-04-11 14:03:19 -0700 (Fri, 11 Apr 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -153,6 +153,14 @@ VolumeFromFile::ReadNifti( const std::string& pathHdr, const bool detached, cons
   volume->SetMetaInfo( META_SPACE, niftiSpace );
   volume->SetMetaInfo( META_SPACE_ORIGINAL, niftiSpace );
 
+  const char xyzt_units = header.GetField<char>( offsetof( struct nifti_1_header, xyzt_units ) );
+  if ( xyzt_units & NIFTI_UNITS_MM )
+    volume->SetMetaInfo( META_SPACE_UNITS_STRING, "mm" );
+  else if ( xyzt_units & NIFTI_UNITS_MICRON )
+    volume->SetMetaInfo( META_SPACE_UNITS_STRING, "micron" );
+  else if ( xyzt_units & NIFTI_UNITS_METER )
+    volume->SetMetaInfo( META_SPACE_UNITS_STRING, "m" );
+
   const short qform_code = header.GetField<short>( offsetof(nifti_1_header,qform_code) );
   const short sform_code = header.GetField<short>( offsetof(nifti_1_header,sform_code) );
 
@@ -300,7 +308,23 @@ VolumeFromFile::ReadNifti( const std::string& pathHdr, const bool detached, cons
     {
     StdErr << "ERROR: could not open Nifti image file " << pathImg << "\n";
     }
-  
+
+  // if we read volume data (as opposed to grid geometry only) then check intent_code and set DataClass accordingly.
+  if ( volume->GetData() )
+    {
+    const short intent_code = header.GetField<short>( 68 );
+    switch ( intent_code )
+      {
+      case NIFTI_INTENT_LABEL:
+      case NIFTI_INTENT_NEURONAME:
+	volume->GetData()->SetDataClass( DATACLASS_LABEL );
+	break;
+      default:
+	volume->GetData()->SetDataClass( DATACLASS_GREY );
+	break;
+      }
+    }
+
   return volume;
 }
 
@@ -343,16 +367,16 @@ VolumeFromFile::WriteNifti
   header.dim_info = 0;
 
   // ndims
-  header.dim[0] = 4;
+  header.dim[0] = 3;
 
   // dimensions
   header.dim[1] = writeVolume->GetDims()[AXIS_X];
   header.dim[2] = writeVolume->GetDims()[AXIS_Y];
   header.dim[3] = writeVolume->GetDims()[AXIS_Z];
   header.dim[4] = 1;
-  header.dim[5] = 0;
-  header.dim[6] = 0;
-  header.dim[7] = 0;
+  header.dim[5] = 1;
+  header.dim[6] = 1;
+  header.dim[7] = 1;
 
   header.pixdim[0] = 1.0;
   header.pixdim[1] = static_cast<float>( writeVolume->m_Delta[AXIS_X] );
@@ -360,6 +384,14 @@ VolumeFromFile::WriteNifti
   header.pixdim[3] = static_cast<float>( writeVolume->m_Delta[AXIS_Z] );
   header.pixdim[4] = 0.0;
   header.pixdim[5] = 0.0;
+
+  const std::string spaceUnits = writeVolume->GetMetaInfo( META_SPACE_UNITS_STRING );
+  if ( spaceUnits == "mm" )
+    header.xyzt_units = NIFTI_UNITS_MM;
+  else if ( (spaceUnits == "micron") || (spaceUnits == "um") )
+    header.xyzt_units = NIFTI_UNITS_MICRON;
+  else if ( (spaceUnits == "m") || (spaceUnits == "meter") )
+    header.xyzt_units = NIFTI_UNITS_METER;
   
   for ( std::map<int,cmtk::AffineXform::MatrixType>::const_iterator it = volume.m_AlternativeIndexToPhysicalMatrices.begin(); it != volume.m_AlternativeIndexToPhysicalMatrices.end(); ++it )
     {
@@ -443,6 +475,11 @@ VolumeFromFile::WriteNifti
       header.bitpix = 8 * sizeof(double);
       break;
     }  
+
+  if ( data->GetDataClass() == DATACLASS_LABEL )
+    header.intent_code = NIFTI_INTENT_LABEL;
+  else
+    header.intent_code = 0;
   
   // determine data range;
   const Types::DataItemRange dataRange = data->GetRange();
@@ -454,6 +491,43 @@ VolumeFromFile::WriteNifti
     memset( header.descrip, 0, sizeof( header.descrip ) );
     strncpy( header.descrip, volume.GetMetaInfo( META_IMAGE_DESCRIPTION ).c_str(), sizeof( header.descrip )-1 );
     }
+
+  // see if we have the Phase Encode Direction from DICOM - set axis information in header if we do
+  if ( volume.MetaKeyExists( META_IMAGE_SLICE_PEDIRECTION ) )
+    {
+    const std::string peDirection = volume.GetMetaInfo( META_IMAGE_SLICE_PEDIRECTION );
+    if ( peDirection == "COL" )
+      header.dim_info = FPS_INTO_DIM_INFO( 1, 2, 3 );
+    else
+      header.dim_info = FPS_INTO_DIM_INFO( 2, 1, 3 );
+    }
+
+  if ( volume.MetaKeyExists( META_IMAGE_SLICEORDER ) )
+    {
+    // here we assume that this is a volume straight out of the DICOM stacker, which keeps slices along dim[3]
+    if ( header.dim_info == 0 ) // see if we previously set dim_info based on PE direction
+      header.dim_info = FPS_INTO_DIM_INFO( 0, 0, 3 ); // if not, we need to set at least the slice direction
+
+    const std::string sliceOrder = volume.GetMetaInfo( META_IMAGE_SLICEORDER );
+    if ( sliceOrder == META_IMAGE_SLICEORDER_SI )
+      header.slice_code = NIFTI_SLICE_SEQ_INC;
+    else if ( sliceOrder == META_IMAGE_SLICEORDER_SD )
+      header.slice_code = NIFTI_SLICE_SEQ_DEC;
+    else if ( sliceOrder == META_IMAGE_SLICEORDER_AI )
+      header.slice_code = NIFTI_SLICE_ALT_INC;
+    else if ( sliceOrder == META_IMAGE_SLICEORDER_AD )
+      header.slice_code = NIFTI_SLICE_ALT_DEC;
+    else if ( sliceOrder == META_IMAGE_SLICEORDER_AI2 )
+      header.slice_code = NIFTI_SLICE_ALT_INC2;
+    else if ( sliceOrder == META_IMAGE_SLICEORDER_AD2 )
+      header.slice_code = NIFTI_SLICE_ALT_DEC2;
+
+    header.slice_start = 0;
+    header.slice_end = header.dim[3]-1;
+
+    header.slice_duration = atof( volume.GetMetaInfo( META_IMAGE_SLICEDURATION ).c_str() ) / 1000; // convert from msec to s for AFNI
+    header.xyzt_units |= NIFTI_UNITS_SEC;
+    }
   
 #ifdef _MSC_VER
   const char *const modestr = "wb";
