@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3281 $
+//  $Revision: 4941 $
 //
-//  $LastChangedDate: 2011-07-26 14:38:18 -0700 (Tue, 26 Jul 2011) $
+//  $LastChangedDate: 2013-10-04 12:49:06 -0700 (Fri, 04 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -77,14 +77,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /********************************************************************
 Array bounds check
 ********************************************************************/
-#define AP_ASSERT
 
-#ifndef AP_ASSERT     //
-#define NO_AP_ASSERT  // This code avoids definition of the
+#ifndef NO_AP_ASSERT     //
+#define AP_ASSERT  // This code avoids definition of the
 #endif                // both AP_ASSERT and NO_AP_ASSERT symbols
-#ifdef NO_AP_ASSERT   //
-#ifdef AP_ASSERT      //
-#undef NO_AP_ASSERT   //
+#ifdef AP_ASSERT   //
+#ifdef NO_AP_ASSERT      //
+#undef AP_ASSERT   //
 #endif                //
 #endif                //
 
@@ -216,7 +215,6 @@ const complex operator*(const real_value_type& lhs, const complex& rhs);
 const complex operator/(const complex& lhs, const complex& rhs);
 const complex operator/(const real_value_type& lhs, const complex& rhs);
 const complex operator/(const complex& lhs, const real_value_type& rhs);
-real_value_type abscomplex(const complex &z);
 const complex conj(const complex &z);
 const complex csqr(const complex &z);
 
@@ -236,9 +234,6 @@ void vmove(double *vdst, const double* vsrc, int N);
 void vmove(float *vdst, const float* vsrc, int N);
 void vmove(complex *vdst, const complex* vsrc, int N);
 
-void vmoveneg(real_value_type *vdst, const real_value_type *vsrc, int N);
-void vmoveneg(complex *vdst, const complex *vsrc, int N);
-
 void vmove(double *vdst, const double *vsrc, int N, double alpha);
 void vmove(float *vdst, const float *vsrc, int N, float alpha);
 void vmove(complex *vdst, const complex *vsrc, int N, real_value_type alpha);
@@ -426,6 +421,8 @@ public:
         m_iHigh1 = -1;
         m_iLow2 = 0;
         m_iHigh2 = -1;
+	m_iConstOffset = 0;
+	m_iLinearMember = 0;
     };
 
     ~template_2d_array()
@@ -447,6 +444,8 @@ public:
         m_iHigh1 = -1;
         m_iLow2 = 0;
         m_iHigh2 = -1;
+	m_iConstOffset = 0;
+	m_iLinearMember = 0;
         if( rhs.m_iVecSize!=0 )
         {
             setbounds(rhs.m_iLow1, rhs.m_iHigh1, rhs.m_iLow2, rhs.m_iHigh2);
@@ -626,12 +625,9 @@ extern const real_value_type maxrealnumber;
 extern const real_value_type minrealnumber;
 
 int sign(real_value_type x);
-real_value_type randomreal();
-int randominteger(int maxv);
 int round(real_value_type x);
 int trunc(real_value_type x);
 int ifloor(real_value_type x);
-int iceil(real_value_type x);
 real_value_type pi();
 real_value_type sqr(real_value_type x);
 int maxint(int m1, int m2);
