@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2012, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3957 $
+//  $Revision: 4948 $
 //
-//  $LastChangedDate: 2012-03-01 15:14:39 -0800 (Thu, 01 Mar 2012) $
+//  $LastChangedDate: 2013-10-08 13:49:31 -0700 (Tue, 08 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -2196,7 +2196,7 @@ lbfgsbminimize
   ap::real_value_type ddum;
   ap::real_value_type dtd;
   ap::real_value_type gd;
-  ap::real_value_type gdold;
+  ap::real_value_type gdold = 0;
   ap::real_value_type stp;
   ap::real_value_type stpmx;
   ap::real_value_type tf;
@@ -2359,13 +2359,6 @@ lbfgsbminimize
       f = fold;
       if( col==0 )
 	{
-	if( internalinfo==0 )
-	  {
-	  internalinfo = -9;
-	  nfgv = nfgv-1;
-	  ifun = ifun-1;
-	  iback = iback-1;
-	  }
 	task = 2;
 	iter = iter+1;
 	functionAndGradient->NextIteration( iter );
@@ -2374,10 +2367,6 @@ lbfgsbminimize
 	}
       else
 	{
-	if( internalinfo==0 )
-	  {
-	  nfgv = nfgv-1;
-	  }
 	internalinfo = 0;
 	col = 0;
 	head = 1;
