@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3193 $
+//  $Revision: 4973 $
 //
-//  $LastChangedDate: 2011-04-28 16:15:14 -0700 (Thu, 28 Apr 2011) $
+//  $LastChangedDate: 2013-10-11 13:31:38 -0700 (Fri, 11 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -204,7 +204,9 @@ bool smatrixtdevd(ap::real_1d_array& d,
             ap::vmove(&z(0, 0), &z1(1, 1), ap::vlen(0,n-1));
             return result;
         }
+#ifndef NO_AP_ASSERT
         ap::ap_error::make_assertion(false, "SMatrixTDEVD: Incorrect ZNeeded!");
+#endif
     }
     return result;
 }
@@ -269,8 +271,9 @@ bool tridiagonalevd(ap::real_1d_array& d,
     int zrows;
     bool wastranspose;
 
+#ifndef NO_AP_ASSERT
     ap::ap_error::make_assertion(zneeded>=0&&zneeded<=3, "TridiagonalEVD: Incorrent ZNeeded");
-    
+#endif    
     //
     // Quick return if possible
     //
