@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4918 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2013-10-03 13:01:32 -0700 (Thu, 03 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -510,7 +510,7 @@ QtTriplanarWindow::UpdateDialog()
       }
     
     QString caption;
-    this->setWindowTitle( caption.sprintf( "CMTK Triplanar Viewer: %s", this->m_Study->GetName() ) );
+    this->setWindowTitle( (std::string( "CMTK Triplanar Viewer: " ) + this->m_Study->GetName()).c_str() );
     this->show();
     }
 }
@@ -537,7 +537,7 @@ QtTriplanarWindow::slotSwitchImageAx( int imageIndex )
 	sliceImage->GetPixelData()->ReplacePaddingData( 0.0 );
       
       sliceImage->AdjustToIsotropic( volume->GetMinDelta(), this->m_InterpolateAction->isChecked() );
-      PipelineImageAx->SetFromScalarImage( sliceImage );
+      PipelineImageAx->SetFromScalarImage( *sliceImage );
       }
     sliceImage = ScalarImage::SmartPtr::Null();
 
@@ -567,7 +567,7 @@ QtTriplanarWindow::slotSwitchImageSa( int imageIndex )
 
   if ( volume ) 
     {
-    ScalarImage *sliceImage = volume->GetOrthoSlice( AXIS_X, imageIndex );
+    ScalarImage::SmartPtr sliceImage = volume->GetOrthoSlice( AXIS_X, imageIndex );
     
     if ( sliceImage ) 
       {
@@ -576,8 +576,7 @@ QtTriplanarWindow::slotSwitchImageSa( int imageIndex )
       
       sliceImage->Mirror( false /* horizontal */, true /* vertical */ );
       sliceImage->AdjustToIsotropic( volume->GetMinDelta(), this->m_InterpolateAction->isChecked() );
-      PipelineImageSa->SetFromScalarImage( sliceImage );
-      delete sliceImage;
+      PipelineImageSa->SetFromScalarImage( *sliceImage );
       }
     
     LocationEntryX->setText( QString::number( volume->GetPlaneCoord( AXIS_X, imageIndex ) ) );
@@ -606,7 +605,7 @@ QtTriplanarWindow::slotSwitchImageCo( int imageIndex )
 
   if ( volume ) 
     {
-    ScalarImage *sliceImage = volume->GetOrthoSlice( AXIS_Y, imageIndex );
+    ScalarImage::SmartPtr sliceImage = volume->GetOrthoSlice( AXIS_Y, imageIndex );
     
     if ( sliceImage ) 
       {
@@ -615,8 +614,7 @@ QtTriplanarWindow::slotSwitchImageCo( int imageIndex )
       
       sliceImage->Mirror( false /* horizontal */, true /* vertical */ );
       sliceImage->AdjustToIsotropic( volume->GetMinDelta(), this->m_InterpolateAction->isChecked() );
-      PipelineImageCo->SetFromScalarImage( sliceImage );
-      delete sliceImage;
+      PipelineImageCo->SetFromScalarImage( *sliceImage );
       }
     
     LocationEntryY->setText( QString::number( volume->GetPlaneCoord( AXIS_Y, imageIndex ) ) );
@@ -644,7 +642,7 @@ QtTriplanarWindow
 ::slotGoToPixel( const QString& xyz )
 {
   int x, y, z;
-  if ( 3 != sscanf( xyz.toLatin1(), "%d,%d,%d", &x, &y, &z ) )
+  if ( 3 != sscanf( xyz.toLatin1(), "%10d,%10d,%10d", &x, &y, &z ) )
     {
     qWarning( "QtTriplanarWindow::slotGoToPixel needs pixel index as 'x,y,z'.\n" );
     }
@@ -660,7 +658,7 @@ void
 QtTriplanarWindow::slotGoToLocation( const QString& xyz )
 {
   float v[3];
-  if ( 3 != sscanf( xyz.toLatin1(), "%f,%f,%f", v, v+1, v+2 ) )
+  if ( 3 != sscanf( xyz.toLatin1(), "%15f,%15f,%15f", v, v+1, v+2 ) )
     {
     qWarning( "QtTriplanarWindow::slotGoToLocation needs 3D coordinate as 'x,y,z'.\n" );
     }
@@ -690,7 +688,7 @@ QtTriplanarWindow
 ::slotSetWindowLevel( const QString& wl )
 {
   float window, level;
-  if ( 2 != sscanf( wl.toLatin1(), "%f:%f", &window, &level ) )
+  if ( 2 != sscanf( wl.toLatin1(), "%15f:%15f", &window, &level ) )
     {
     qWarning( "QtTriplanarWindow::slotSetWindowLevel needs 'window:level'.\n" );
     }
