@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2010 SRI International
+//  Copyright 2004-2010, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3583 $
+//  $Revision: 4882 $
 //
-//  $LastChangedDate: 2011-11-29 13:41:49 -0800 (Tue, 29 Nov 2011) $
+//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -44,9 +44,10 @@ cmtk
 //@{
 
 QtWindowLevelControls::QtWindowLevelControls
-( QWidget *const parent )
-  : QWidget( parent ),
-    m_Study( NULL )
+( QWidget *const myParent )
+  : QWidget( myParent ),
+    m_Study( NULL ),
+    RangeFrom( 0.0 ), RangeTo( 1.0 ), RangeWidth( 1.0 )
 {
   Layout = new QVBoxLayout( this );
   Layout->setContentsMargins( 5, 5, 5, 5 );
