@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5129 $
+//  $Revision: 5316 $
 //
-//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
+//  $LastChangedDate: 2014-04-11 13:43:18 -0700 (Fri, 11 Apr 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -193,6 +193,32 @@ AffineRegistrationCommandLine
     throw cmtk::ExitException( 1 );
     }
 
+  // check for supported numbers of degrees of freedom
+  const std::set<short> supportedDOFs = AffineXform::GetSupportedDOFs();
+  for ( std::vector<short>::iterator it = this->NumberDOFs.begin(); it != this->NumberDOFs.end(); ++it )
+    {
+    if ( *it == 603 ) // fix legacy value
+      *it = 3303;
+
+    if ( supportedDOFs.find( *it ) == supportedDOFs.end() )
+      {
+      StdErr << "ERROR: DOF number " << *it << " is not supported.\n";
+      throw cmtk::ExitException( 1 );
+      }
+    }
+  // check for supported numbers of degrees of freedom
+  for ( std::vector<short>::iterator it = this->NumberDOFsFinal.begin(); it != this->NumberDOFsFinal.end(); ++it )
+    {
+    if ( *it == 603 ) // fix legacy value
+      *it = 3303;
+
+    if ( supportedDOFs.find( *it ) == supportedDOFs.end() )
+      {
+      StdErr << "ERROR: DOF number " << *it << " is not supported.\n";
+      throw cmtk::ExitException( 1 );
+      }
+    }
+
   this->SetInitialTransformation( AffineXform::SmartPtr( new AffineXform() ) );
     
   if ( ! clArg2.empty() ) 
