@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 4907 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2013-10-01 11:49:29 -0700 (Tue, 01 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -378,7 +378,7 @@ CongealingFunctional<TXform>
 	  }
 	}
       
-      if ( count )
+      if ( count > 1 ) // count>0 not enough for unbiased estimate of sdev below
 	{
 	const double mu = sum / count;
 	const byte sdev = std::min<byte>( ThisConst->m_HistogramKernelRadiusMax, (byte)(sqrt(( count * mu * mu - 2 * mu * sum + sumsq ) / (count-1)) ) );
@@ -426,7 +426,7 @@ CongealingFunctional<TXform>
 	  }
 	}
       
-      if ( count )
+      if ( count > 1 )
 	{
 	const double mu = sum / count;
 	const byte sdev = std::min<byte>( ThisConst->m_HistogramKernelRadiusMax, (byte)(sqrt(( count * mu * mu - 2 * mu * sum + sumsq ) / (count-1)) ) );
