@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3728 $
+//  $Revision: 4344 $
 //
-//  $LastChangedDate: 2012-01-19 14:23:36 -0800 (Thu, 19 Jan 2012) $
+//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -45,8 +45,6 @@
 
 #include <vector>
 
-#include <IO/cmtkClassStream.h>
-
 namespace
 cmtk
 {
