@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4344 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -206,7 +206,6 @@ protected:
     const byte paddingValue = This->m_PaddingValue;
     const byte backgroundValue = This->m_UserBackgroundFlag ? This->m_PrivateUserBackgroundValue : paddingValue;
     
-    UniformVolume::CoordinateVectorType v;
     byte value;
     const byte* dataPtr = static_cast<const byte*>( target->GetData()->GetDataPtr() );
     
@@ -217,8 +216,7 @@ protected:
     for ( size_t i = startIdx; i < endIdx; ++i, ++wptr )
       {
       const size_t offset = This->m_ProbabilisticSamples[i];
-      v = This->m_TemplateGrid->GetGridLocation( offset );
-      xform->ApplyInPlace( v );
+      const UniformVolume::CoordinateVectorType v = xform->Apply( This->m_TemplateGrid->GetGridLocation( offset ) );
       
       if ( target->ProbeData( value, dataPtr, v ) )
 	{
