@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -34,6 +34,10 @@
 
 #include <Base/cmtkUniformVolume.h>
 #include <IO/cmtkVolumeIO.h>
+
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
+
 #include <IO/cmtkClassStreamAffineXform.h>
 
 namespace
@@ -43,14 +47,14 @@ cmtk
 /** \addtogroup Registration */
 //@{
 
-ClassStream& 
+ClassStreamOutput& 
 operator<<
-  ( ClassStream& stream, const GroupwiseRegistrationFunctionalXformTemplate<SplineWarpXform>& func )
+  ( ClassStreamOutput& stream, const GroupwiseRegistrationFunctionalXformTemplate<SplineWarpXform>& func )
 {
   stream.Begin( "template" );
   stream.WriteIntArray( "dims", func.m_TemplateGrid->GetDims().begin(), 3 );
   stream.WriteCoordinateArray( "delta", func.m_TemplateGrid->Deltas().begin(), 3 );
-  stream.WriteCoordinateArray( "size", func.m_TemplateGrid->Size.begin(), 3 );
+  stream.WriteCoordinateArray( "size", func.m_TemplateGrid->m_Size.begin(), 3 );
   stream.WriteCoordinateArray( "origin", func.m_TemplateGrid->m_Offset.begin(), 3 );
   stream.End();
   
@@ -63,9 +67,9 @@ operator<<
   return stream;
 }
 
-ClassStream& 
+ClassStreamInput& 
 operator>>
-( ClassStream& stream,  GroupwiseRegistrationFunctionalXformTemplate<SplineWarpXform>& func )
+( ClassStreamInput& stream,  GroupwiseRegistrationFunctionalXformTemplate<SplineWarpXform>& func )
 {
   if ( ! stream.Seek( "template" ) )
     {
@@ -81,8 +85,8 @@ operator>>
   stream.ReadCoordinateArray( "origin", origin, 3 );
   stream.End();
   
-  UniformVolume::SmartPtr templateGrid( new UniformVolume( UniformVolume::IndexType( dims ), UniformVolume::CoordinateVectorType( size ) ) );
-  templateGrid->SetOffset( FixedVector<3,Types::Coordinate>( origin ) );
+  UniformVolume::SmartPtr templateGrid( new UniformVolume( UniformVolume::IndexType::FromPointer( dims ), UniformVolume::CoordinateVectorType::FromPointer( size ) ) );
+  templateGrid->SetOffset( FixedVector<3,Types::Coordinate>::FromPointer( origin ) );
 
   std::vector<UniformVolume::SmartPtr> imageVector;
   std::vector<AffineXform::SmartPtr> xformVector;
