@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4873 $
+//  $Revision: 5309 $
 //
-//  $LastChangedDate: 2013-09-24 12:53:12 -0700 (Tue, 24 Sep 2013) $
+//  $LastChangedDate: 2014-04-10 18:01:34 -0700 (Thu, 10 Apr 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -173,7 +173,7 @@ ImagePairAffineRegistration
 
     if ( this->m_RestrictToInPlane >=0 )
       {
-      StdErr << "WARNING: cannot restrict transformation to in-plane when symmetric computation is used; ignoring this.\n";
+      functional->SetRestrictToInPlane( this->m_RestrictToInPlane );
       }
     
     return functional;
