@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4093 $
+//  $Revision: 4423 $
 //
-//  $LastChangedDate: 2012-03-27 13:05:25 -0700 (Tue, 27 Mar 2012) $
+//  $LastChangedDate: 2012-06-11 16:13:37 -0700 (Mon, 11 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -36,7 +36,6 @@
 #include <cmtkconfig.h>
 
 #include <Base/cmtkSplineWarpXform.h>
-#include <Base/cmtkLandmarkPairList.h>
 
 #include <Registration/cmtkImagePairRegistration.h>
 
@@ -53,7 +52,7 @@ cmtk
  * By implementing member functions to retrieve parameters and report results
  * in derived classes, registration can be integrated into various 
  * environments.
- *\version $Revision: 4093 $ $Date: 2012-03-27 13:05:25 -0700 (Tue, 27 Mar 2012) $
+ *\version $Revision: 4423 $ $Date: 2012-06-11 16:13:37 -0700 (Mon, 11 Jun 2012) $
  */
 class ImagePairNonrigidRegistration : 
   /// Inherit basic voxel registration functions.
@@ -141,9 +140,6 @@ protected:
    */
   cmtkGetSetMacro(float,InverseConsistencyWeight);
 
-  /// Weighting factor of landmark registration error vs. image similarity.
-  cmtkGetSetMacro(float,LandmarkErrorWeight);
-
   /// Flag to turn on deformation unfolding before each level.
   bool m_RelaxToUnfold;
 
@@ -191,9 +187,6 @@ protected:
   const UniformVolume::SmartPtr GetReformattedFloatingImage( Interpolators::InterpolationEnum interpolator = Interpolators::LINEAR ) const;
 
 private:
-  /// (Optional) matched landmark list.
-  LandmarkPairList::SmartConstPtr m_LandmarkPairs;
-
   /// Level on which the last control grid refinement was performend.
   int RefinedGridAtLevel;
 
