@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3743 $
+//  $Revision: 4093 $
 //
-//  $LastChangedDate: 2012-01-25 15:40:11 -0800 (Wed, 25 Jan 2012) $
+//  $LastChangedDate: 2012-03-27 13:05:25 -0700 (Tue, 27 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -212,9 +212,9 @@ protected:
     if ( !finite( result ) ) 
       return -FLT_MAX;
     
-    if ( this->m_MatchedLandmarkList ) 
+    if ( this->m_LandmarkPairs ) 
       {
-      result -= this->m_LandmarkErrorWeight * warp.GetLandmarksMSD( this->m_MatchedLandmarkList );
+      result -= this->m_LandmarkErrorWeight * warp.GetLandmarksMSD( *(this->m_LandmarkPairs) );
       }
 
     if ( this->m_InverseTransformation ) 
