@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2012, 2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4364 $
+//  $Revision: 5309 $
 //
-//  $LastChangedDate: 2012-05-29 15:45:24 -0700 (Tue, 29 May 2012) $
+//  $LastChangedDate: 2014-04-10 18:01:34 -0700 (Thu, 10 Apr 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -74,6 +74,9 @@ public:
   /// Set flag and value for forcing values outside the floating image.
   virtual void SetForceOutside( const bool flag = true, const Types::DataItem value = 0 ) = 0;
 
+  /// Set optional restriction to axis-orthogonal in-plane transformations.
+  virtual void SetRestrictToInPlane( const int axis ) = 0;
+
   /// Constructor function.
   static ImagePairSymmetricAffineRegistrationFunctional* Create
   ( const int metric, UniformVolume::SmartPtr& refVolume, UniformVolume::SmartPtr& fltVolume, const Interpolators::InterpolationEnum interpolation, AffineXform::SmartPtr& affineXform );
