@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4538 $
+//  $Revision: 4882 $
 //
-//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
+//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -46,13 +46,16 @@
 
 cmtk::ImageSymmetryPlaneCommandLineBase
 ::ImageSymmetryPlaneCommandLineBase()
-  : m_MinValueSet( false ),
-    m_MaxValueSet( false ),
+  : m_MinValue( 0.0 ), m_MinValueSet( false ),
+    m_MaxValue( 0.0 ), m_MaxValueSet( false ),
     m_Sampling( 1.0 ),
     m_Accuracy( 0.1 ),
     m_Interpolation( Interpolators::LINEAR ),
     m_Levels( 4 ),
     m_DisableOptimization( false ),
+    m_Rho( 0.0 ),
+    m_Theta( 0.0 ),
+    m_Phi( 0.0 ),
     m_FixOffset( false ),
     m_MirrorOutFile( NULL ),
     m_AlignedOutFile( NULL ),
@@ -65,7 +68,6 @@ cmtk::ImageSymmetryPlaneCommandLineBase
     m_SymmetryOutFileName( NULL ),
     m_SymmetryParameters( NULL ),
     m_SymmetryParametersFile( NULL ),
-    m_InFileName( NULL ),
     m_InitialPlane( SYMPL_INIT_YZ ),
     m_CommandLine( CommandLine::PROPS_XML )
 {
@@ -141,7 +143,7 @@ cmtk::ImageSymmetryPlaneCommandLineBase
   UniformVolume::SmartPtr originalVolume( VolumeIO::ReadOriented( this->m_InFileName ) );
   if ( !originalVolume ) 
     {
-    StdErr.printf( "Could not read image file %s\n", this->m_InFileName );
+    StdErr.printf( "Could not read image file %s\n", this->m_InFileName.c_str() );
     return 1;
     }
 
@@ -271,7 +273,7 @@ cmtk::ImageSymmetryPlaneCommandLineBase
     if ( this->m_SymmetryParameters ) 
       {
       double rho, theta, phi;
-      if ( 3 == sscanf( this->m_SymmetryParameters, "%lf %lf %lf", &rho, &theta, &phi ) ) 
+      if ( 3 == sscanf( this->m_SymmetryParameters, "%20lf %20lf %20lf", &rho, &theta, &phi ) ) 
 	{
 	this->m_Rho = rho; 
 	this->m_Theta = Units::Degrees( theta );
