@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4381 $
+//  $Revision: 4907 $
 //
-//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
+//  $LastChangedDate: 2013-10-01 11:49:29 -0700 (Tue, 01 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -38,6 +38,7 @@
 #include <System/cmtkThreadPool.h>
 #include <System/cmtkThreadParameterArray.h>
 #include <System/cmtkDebugOutput.h>
+#include <System/cmtkExitException.h>
 
 #include <algorithm>
 
@@ -174,7 +175,13 @@ SplineWarpCongealingFunctional
       {
       for ( size_t i = 0; i < this->m_XformVector.size(); ++i )
 	{
-	constraint += dynamic_cast<const SplineWarpXform*>( this->m_XformVector[i].GetPtr() )->GetJacobianConstraint();
+	const SplineWarpXform* splineWarp = dynamic_cast<const SplineWarpXform*>( this->m_XformVector[i].GetPtr() );
+	if ( ! splineWarp )
+	  {
+	  StdErr << "ERROR: dynamic_cast to SplineWarpXform failed in SplineWarpCongealingFunctional::Evaluate()\n";
+	  throw ExitException( 1 );
+	  }
+	constraint += splineWarp->GetJacobianConstraint();
 	}
       }
     return result - this->m_JacobianConstraintWeight * constraint;
