@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4381 $
+//  $Revision: 4824 $
 //
-//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
+//  $LastChangedDate: 2013-09-11 12:13:30 -0700 (Wed, 11 Sep 2013) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -322,7 +322,7 @@ protected:
   /// Constructor.
   VoxelMatchingElasticFunctional_WarpTemplate( UniformVolume::SmartPtr& reference, UniformVolume::SmartPtr& floating )
     : VoxelMatchingElasticFunctional( reference, floating ),
-      Warp( NULL ), InverseTransformation( NULL )
+      Warp( NULL ), InverseTransformation( NULL ), InverseConsistencyWeight( 0.0 )
   {}
   
   /// Dummy virtual destructor.
