@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2010 SRI International
+//  Copyright 2004-2010, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 2022 $
+//  $Revision: 4873 $
 //
-//  $LastChangedDate: 2010-07-21 15:26:03 -0700 (Wed, 21 Jul 2010) $
+//  $LastChangedDate: 2013-09-24 12:53:12 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,7 +41,9 @@ cmtk
 
 VoxelMatchingMeanSquaredDifference::VoxelMatchingMeanSquaredDifference
 ( const UniformVolume* refVolume, const UniformVolume* fltVolume ) :
-  VoxelMatchingMetricShort( refVolume, fltVolume )
+  VoxelMatchingMetricShort( refVolume, fltVolume ),
+  Sum( 0.0 ),
+  Samples( 0 )
 {}
 
 } // namespace cmtk
