@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5344 $
+//  $Revision: 5355 $
 //
-//  $LastChangedDate: 2014-05-01 14:23:38 -0700 (Thu, 01 May 2014) $
+//  $LastChangedDate: 2014-05-09 16:55:27 -0700 (Fri, 09 May 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -77,6 +77,7 @@ public:
       m_SphereExcludeSafetyMargin( 10.0 ),
       m_ErodeSNR( 10.0 ), 
       m_ErodeCNR( 5.0 ),
+      m_Erode10mm( 1.0 ),
       m_RefineXformEachLandmark( false ),
       m_RefineOutliers( false ),
       m_ExcludeOutliers( false ),
@@ -116,6 +117,9 @@ public:
     /// Erode CNR spheres by this many pixels for SNR computation
     Types::Coordinate m_ErodeCNR;
 
+    /// Erode 10mm spheres by this many pixels for brightness computation
+    Types::Coordinate m_Erode10mm;
+
     /// Flag for optional refinement of transformation after each new landmark has been added.
     bool m_RefineXformEachLandmark;
     
