@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4819 $
+//  $Revision: 5360 $
 //
-//  $LastChangedDate: 2013-09-10 11:50:38 -0700 (Tue, 10 Sep 2013) $
+//  $LastChangedDate: 2014-06-24 17:33:04 -0700 (Tue, 24 Jun 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -201,10 +201,10 @@ CompressedStream::GetBaseName( const std::string& path )
   
   if ( suffixPos != std::string::npos ) 
     {
+    const std::string fileSuffix = path.substr( suffixPos, std::string::npos );
     for ( int i = 0; ArchiveLookup[i].suffix; ++i )
       {
-      const size_t suffixLen = strlen( ArchiveLookup[i].suffix );
-      if ( !path.compare( suffixPos, suffixLen, ArchiveLookup[i].suffix, suffixLen ) )
+      if ( fileSuffix == ArchiveLookup[i].suffix )
 	{
 	return path.substr( 0, suffixPos );
 	}
