@@ -24,11 +24,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4830 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2013-09-11 14:23:35 -0700 (Wed, 11 Sep 2013) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -54,10 +54,19 @@ CompressedStream::File::File( const std::string& filename )
     }
 }
 
+CompressedStream::File::~File()
+{
+  this->Close();
+}
+
 void 
 CompressedStream::File::Close()
 {
-  fclose( this->m_File );
+  if ( this->m_File )
+    {
+    fclose( this->m_File );
+    this->m_File = NULL;
+    }
 }
 
 void
