@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3812 $
+//  $Revision: 4260 $
 //
-//  $LastChangedDate: 2012-02-02 15:52:58 -0800 (Thu, 02 Feb 2012) $
+//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,9 +41,9 @@ namespace
 cmtk
 {
 
-CompressedStream::LZMA::LZMA( const char* filename )
+CompressedStream::LZMA::LZMA( const std::string& filename )
 {
-  this->m_File = lzmadec_open( filename );
+  this->m_File = lzmadec_open( filename.c_str() );
   if ( !this->m_File ) 
     {
     StdErr << "ERROR: lzmadec_open() failed for file '" << filename << "'\n";
