@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3299 $
+//  $Revision: 4876 $
 //
-//  $LastChangedDate: 2011-07-27 10:51:27 -0700 (Wed, 27 Jul 2011) $
+//  $LastChangedDate: 2013-09-24 13:09:58 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -659,7 +659,7 @@ FilterVolumeCoupe::CoupeFilter
           int offset = x + dimX * ( y + dimY * z );
           NLsPerVoxelHist[NLsPerVoxel.at( offset )->size()]++;
           Types::DataItem curNLSum = 0.0;
-          for ( std::vector<Types::DataItem>::iterator it = NLsPerVoxel.at( offset )->begin(); it != NLsPerVoxel.at( offset )->end(); it++ )
+          for ( std::vector<Types::DataItem>::iterator it = NLsPerVoxel.at( offset )->begin(); it != NLsPerVoxel.at( offset )->end(); ++it )
             curNLSum += *it;
 
           Types::DataItem restoredVoxel = curNLSum / NLsPerVoxel.at( offset )->size();
@@ -671,7 +671,7 @@ FilterVolumeCoupe::CoupeFilter
             {
             std::cout << std::endl;
             std::cout << std::endl;
-            for ( std::vector<Types::DataItem>::iterator it = NLsPerVoxel.at( offset )->begin(); it != NLsPerVoxel.at( offset )->end(); it++ )
+            for ( std::vector<Types::DataItem>::iterator it = NLsPerVoxel.at( offset )->begin(); it != NLsPerVoxel.at( offset )->end(); ++it )
               {
               std::cout << *it << "..." << "\n";
               }
